@@ -13,14 +13,14 @@
 #ifndef CATALOG_H
 #define CATALOG_H
 
-#include "pos.h"
-#include "catalogstring.h"
-#include "catalogcapabilities.h"
-#include "note.h"
-#include "state.h"
-#include "phase.h"
 #include "alttrans.h"
 #include "catalog_private.h"
+#include "catalogcapabilities.h"
+#include "catalogstring.h"
+#include "note.h"
+#include "phase.h"
+#include "pos.h"
+#include "state.h"
 class CatalogStorage;
 class MassReplaceJob;
 class KAutoSaveFile;
@@ -33,14 +33,12 @@ class CatalogImportPlugin;
 class CatalogExportPlugin;
 }
 
-
 bool isApproved(TargetState state, ProjectLocal::PersonRole role);
-bool isApproved(TargetState state); //disregarding Phase
+bool isApproved(TargetState state); // disregarding Phase
 TargetState closestState(bool approved, ProjectLocal::PersonRole role);
-int findPrevInList(const std::list<int>& list, int index);
-int findNextInList(const std::list<int>& list, int index);
-void insertInList(std::list<int>& list, int index); // insert index in the right place in the list
-
+int findPrevInList(const std::list<int> &list, int index);
+int findNextInList(const std::list<int> &list, int index);
+void insertInList(std::list<int> &list, int index); // insert index in the right place in the list
 
 /**
  * This class represents a catalog
@@ -49,60 +47,60 @@ void insertInList(std::list<int>& list, int index); // insert index in the right
  *
  * @short Wrapper class that represents a translation catalog
  * @author Nick Shaforostoff <shafff@ukr.net>
-*/
-class Catalog: public QUndoStack
+ */
+class Catalog : public QUndoStack
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.Lokalize.FileContainer")
 
 public:
-    explicit Catalog(QObject* parent);
-    virtual ~Catalog() override;
+    explicit Catalog(QObject *parent);
+    ~Catalog() override;
 
-    QString msgid(const DocPosition&) const;
-    virtual QString msgstr(const DocPosition&) const;
-    QString msgidWithPlurals(const DocPosition&, bool truncateFirstLine) const;
-    QString msgstrWithPlurals(const DocPosition&, bool truncateFirstLine) const;
+    QString msgid(const DocPosition &) const;
+    virtual QString msgstr(const DocPosition &) const;
+    QString msgidWithPlurals(const DocPosition &, bool truncateFirstLine) const;
+    QString msgstrWithPlurals(const DocPosition &, bool truncateFirstLine) const;
 
     static QStringList supportedExtensions();
-    static bool extIsSupported(const QString& path);
+    static bool extIsSupported(const QString &path);
     static QStringList translatedStates();
 
     int capabilities() const;
 
-    void push(QUndoCommand* cmd);
+    void push(QUndoCommand *cmd);
 
-public Q_SLOTS: //DBus interface
-    QString source(const DocPosition& pos) const
+public Q_SLOTS: // DBus interface
+    QString source(const DocPosition &pos) const
     {
         return msgid(pos);
     }
-    QString target(const DocPosition& pos) const
+    QString target(const DocPosition &pos) const
     {
         return msgstr(pos);
     }
     // used by XLIFF storage)
-    CatalogString sourceWithTags(const DocPosition& pos) const;
-    CatalogString targetWithTags(const DocPosition& pos) const;
-    CatalogString catalogString(const DocPosition& pos) const;
+    CatalogString sourceWithTags(const DocPosition &pos) const;
+    CatalogString targetWithTags(const DocPosition &pos) const;
+    CatalogString catalogString(const DocPosition &pos) const;
 
     /**
      * @a pos.form is note number
      * @returns previous note contents, if any
      */
-    Note setNote(const DocPosition& pos, const Note& note);
-    QVector<Note> notes(const DocPosition& pos) const;
-    QVector<Note> developerNotes(const DocPosition& pos) const;
+    Note setNote(const DocPosition &pos, const Note &note);
+    QVector<Note> notes(const DocPosition &pos) const;
+    QVector<Note> developerNotes(const DocPosition &pos) const;
     QStringList noteAuthors() const;
-    QVector<AltTrans> altTrans(const DocPosition& pos) const;
-    QStringList sourceFiles(const DocPosition& pos) const;
-    //QString msgctxt(uint index) const;
-    //the result is guaranteed to have at least 1 string
-    QStringList context(const DocPosition& pos) const;
-    QString id(const DocPosition& pos) const;
+    QVector<AltTrans> altTrans(const DocPosition &pos) const;
+    QStringList sourceFiles(const DocPosition &pos) const;
+    // QString msgctxt(uint index) const;
+    // the result is guaranteed to have at least 1 string
+    QStringList context(const DocPosition &pos) const;
+    QString id(const DocPosition &pos) const;
     ///@returns previous phase-name
-    QString setPhase(const DocPosition& pos, const QString& phase);
-    QString phase(const DocPosition& pos) const;
+    QString setPhase(const DocPosition &pos, const QString &phase);
+    QString phase(const DocPosition &pos) const;
     QString activePhase() const
     {
         return d._phase;
@@ -111,29 +109,29 @@ public Q_SLOTS: //DBus interface
     {
         return d._phaseRole;
     }
-    void setActivePhase(const QString& phase, ProjectLocal::PersonRole role = ProjectLocal::Approver);
-    Phase phase(const QString& name) const;
+    void setActivePhase(const QString &phase, ProjectLocal::PersonRole role = ProjectLocal::Approver);
+    Phase phase(const QString &name) const;
     QList<Phase> allPhases() const;
     QMap<QString, Tool> allTools() const;
-    QVector<Note> phaseNotes(const QString& phase) const;
+    QVector<Note> phaseNotes(const QString &phase) const;
     ///@arg pos.entry - number of phase, @arg pos.form - number of note
-    QVector<Note> setPhaseNotes(const QString& phase, QVector<Note>);
+    QVector<Note> setPhaseNotes(const QString &phase, QVector<Note>);
 
     bool isPlural(uint index) const;
-    bool isPlural(const DocPosition& pos) const
+    bool isPlural(const DocPosition &pos) const
     {
         return isPlural(pos.entry);
     }
     bool isApproved(uint index) const;
-    bool isApproved(const DocPosition& pos) const
+    bool isApproved(const DocPosition &pos) const
     {
         return isApproved(pos.entry);
     }
-    TargetState state(const DocPosition& pos) const;
-    bool isEquivTrans(const DocPosition&) const;
+    TargetState state(const DocPosition &pos) const;
+    bool isEquivTrans(const DocPosition &) const;
     ///@returns true if at least one form is untranslated
     bool isEmpty(uint index) const;
-    bool isEmpty(const DocPosition&) const;
+    bool isEmpty(const DocPosition &) const;
     bool isModified(DocPos entry) const;
     bool isModified(int entry) const;
     bool isObsolete(int entry) const;
@@ -141,7 +139,7 @@ public Q_SLOTS: //DBus interface
     /// so DocPosition::entry may actually be < size()+binUnitsCount()
     int binUnitsCount() const;
 
-    int unitById(const QString& id) const;
+    int unitById(const QString &id) const;
 
     bool isBookmarked(uint index) const
     {
@@ -165,7 +163,7 @@ public Q_SLOTS: //DBus interface
 
 public:
     QString originalOdfFilePath();
-    void setOriginalOdfFilePath(const QString&);
+    void setOriginalOdfFilePath(const QString &);
 
     int firstFuzzyIndex() const
     {
@@ -221,6 +219,7 @@ public:
     {
         return d._autoSaveRecovered;
     }
+
 public:
     void clear();
     bool isEmpty()
@@ -232,27 +231,26 @@ public:
         return d._readOnly;
     }
 
-    void attachAltTransCatalog(Catalog*);
-    void attachAltTrans(int entry, const AltTrans& trans);
+    void attachAltTransCatalog(Catalog *);
+    void attachAltTrans(int entry, const AltTrans &trans);
 
+    virtual const DocPosition &undo();
+    virtual const DocPosition &redo();
 
-    virtual const DocPosition& undo();
-    virtual const DocPosition& redo();
+    void setTarget(DocPosition pos, const CatalogString &s); // for batch use only!
 
-    void setTarget(DocPosition pos, const CatalogString& s); //for batch use only!
-
-    //void setErrorIndex(const QList<int>& errors){d._errorIndex=errors;}
-    void setUrl(const QString& u)
+    // void setErrorIndex(const QList<int>& errors){d._errorIndex=errors;}
+    void setUrl(const QString &u)
     {
-        d._filePath = u;   //used for template load
+        d._filePath = u; // used for template load
     }
-public Q_SLOTS: //DBus interface
-    const QString& url() const
+public Q_SLOTS: // DBus interface
+    const QString &url() const
     {
         return d._filePath;
     }
     ///@returns 0 if success, >0 erroneous line (parsing error)
-    int loadFromUrl(const QString& url, const QString& saidUrl = QString(), int* fileSize = nullptr, bool fast = false);
+    int loadFromUrl(const QString &url, const QString &saidUrl = QString(), int *fileSize = nullptr, bool fast = false);
     bool saveToUrl(QString url);
     bool save();
     QByteArray contents();
@@ -261,14 +259,14 @@ public Q_SLOTS: //DBus interface
     CatalogType type();
     QString sourceLangCode() const;
     QString targetLangCode() const;
-    void setTargetLangCode(const QString& targetLangCode);
+    void setTargetLangCode(const QString &targetLangCode);
     /**
      * updates DB for _posBuffer and accompanying _originalForLastModified
      */
     void flushUpdateDBBuffer();
 
 protected:
-    virtual KAutoSaveFile* checkAutoSave(const QString& url);
+    virtual KAutoSaveFile *checkAutoSave(const QString &url);
 
 protected Q_SLOTS:
     void doAutoSave();
@@ -284,8 +282,8 @@ protected:
      * (EDITING)
      * accessed from undo/redo code
      * called _BEFORE_ modification
-    */
-    void setLastModifiedPos(const DocPosition&);
+     */
+    void setLastModifiedPos(const DocPosition &);
 
     /**
      * (EDITING)
@@ -293,14 +291,14 @@ protected:
      * accessed from mergeCatalog)
      * it _does_ check if action should be taken
      */
-    void setApproved(const DocPosition& pos, bool approved);
-    void targetDelete(const DocPosition& pos, int count);
-    void targetInsert(const DocPosition& pos, const QString& arg);
-    InlineTag targetDeleteTag(const DocPosition& pos);
-    void targetInsertTag(const DocPosition& pos, const InlineTag& tag);
-    TargetState setState(const DocPosition& pos, TargetState state);
-    Phase updatePhase(const Phase& phase);
-    void setEquivTrans(const DocPosition&, bool equivTrans);
+    void setApproved(const DocPosition &pos, bool approved);
+    void targetDelete(const DocPosition &pos, int count);
+    void targetInsert(const DocPosition &pos, const QString &arg);
+    InlineTag targetDeleteTag(const DocPosition &pos);
+    void targetInsertTag(const DocPosition &pos, const InlineTag &tag);
+    TargetState setState(const DocPosition &pos, TargetState state);
+    Phase updatePhase(const Phase &phase);
+    void setEquivTrans(const DocPosition &, bool equivTrans);
 
     /// @returns true if entry wasn't modified before
     bool setModified(DocPos entry, bool modif);
@@ -326,21 +324,19 @@ protected:
     friend class MassReplaceJob;
 
 public:
-    //static QString supportedMimeFilters;
+    // static QString supportedMimeFilters;
     static QString supportedFileTypes(bool includeTemplates = true);
 
 Q_SIGNALS:
-    void signalEntryModified(const DocPosition&);
+    void signalEntryModified(const DocPosition &);
     void activePhaseChanged();
     void signalNumberOfFuzziesChanged();
     void signalNumberOfEmptyChanged();
     Q_SCRIPTABLE void signalFileLoaded();
-    void signalFileLoaded(const QString&);
+    void signalFileLoaded(const QString &);
     Q_SCRIPTABLE void signalFileSaved();
-    void signalFileSaved(const QString&);
-    void signalFileAutoSaveFailed(const QString&);
+    void signalFileSaved(const QString &);
+    void signalFileAutoSaveFailed(const QString &);
 };
 
-
 #endif
-
