@@ -13,22 +13,22 @@
 
 #include <QString>
 
+#include "catalog.h"
 #include "catalog_private.h"
 #include "catalogitem_private.h"
-#include "catalog.h"
 #include "project.h"
 
 #include <klocalizedstring.h>
 
-
-//BEGIN LokalizeUnitCmd
-LokalizeUnitCmd::LokalizeUnitCmd(Catalog *catalog, const DocPosition& pos, const QString& name = QString())
+// BEGIN LokalizeUnitCmd
+LokalizeUnitCmd::LokalizeUnitCmd(Catalog *catalog, const DocPosition &pos, const QString &name = QString())
     : QUndoCommand(name)
     , _catalog(catalog)
     , _pos(pos)
-{}
+{
+}
 
-static QString setPhaseForPart(Catalog* catalog, const QString& phase, DocPosition phasePos, DocPosition::Part part)
+static QString setPhaseForPart(Catalog *catalog, const QString &phase, DocPosition phasePos, DocPosition::Part part)
 {
     phasePos.part = part;
     return catalog->setPhase(phasePos, phase);
@@ -39,7 +39,7 @@ void LokalizeUnitCmd::redo()
     setJumpingPos();
     doRedo();
     _firstModificationForThisEntry = _catalog->setModified(DocPos(_pos), true);
-//    _prevPhase=setPhaseForPart(_catalog,_catalog->activePhase(),_pos,DocPosition::UndefPart);
+    //    _prevPhase=setPhaseForPart(_catalog,_catalog->activePhase(),_pos,DocPosition::UndefPart);
 }
 
 void LokalizeUnitCmd::undo()
@@ -48,19 +48,20 @@ void LokalizeUnitCmd::undo()
     doUndo();
     if (_firstModificationForThisEntry)
         _catalog->setModified(DocPos(_pos), false);
-//    setPhaseForPart(_catalog,_prevPhase,_pos,DocPosition::UndefPart);
+    //    setPhaseForPart(_catalog,_prevPhase,_pos,DocPosition::UndefPart);
 }
 
 void LokalizeUnitCmd::setJumpingPos()
 {
     _catalog->setLastModifiedPos(_pos);
 }
-//END LokalizeUnitCmd
+// END LokalizeUnitCmd
 
-//BEGIN LokalizeTargetCmd
-LokalizeTargetCmd::LokalizeTargetCmd(Catalog *catalog, const DocPosition& pos, const QString& name = QString())
+// BEGIN LokalizeTargetCmd
+LokalizeTargetCmd::LokalizeTargetCmd(Catalog *catalog, const DocPosition &pos, const QString &name = QString())
     : LokalizeUnitCmd(catalog, pos, name)
-{}
+{
+}
 
 void LokalizeTargetCmd::redo()
 {
@@ -73,29 +74,26 @@ void LokalizeTargetCmd::undo()
     LokalizeUnitCmd::undo();
     setPhaseForPart(_catalog, _prevTargetPhase, _pos, DocPosition::Target);
 }
-//END LokalizeTargetCmd
+// END LokalizeTargetCmd
 
-//BEGIN InsTextCmd
-InsTextCmd::InsTextCmd(Catalog *catalog, const DocPosition& pos, const QString& str)
+// BEGIN InsTextCmd
+InsTextCmd::InsTextCmd(Catalog *catalog, const DocPosition &pos, const QString &str)
     : LokalizeTargetCmd(catalog, pos, i18nc("@item Undo action item", "Insertion"))
     , _str(str)
-{}
+{
+}
 
 bool InsTextCmd::mergeWith(const QUndoCommand *other)
 {
-    const DocPosition otherPos = static_cast<const LokalizeUnitCmd*>(other)->pos();
-    if ((other->id() != id())
-        || (otherPos.entry != _pos.entry)
-        || (otherPos.form != _pos.form)
-        || (otherPos.offset != _pos.offset + _str.size())
-       )
+    const DocPosition otherPos = static_cast<const LokalizeUnitCmd *>(other)->pos();
+    if ((other->id() != id()) || (otherPos.entry != _pos.entry) || (otherPos.form != _pos.form) || (otherPos.offset != _pos.offset + _str.size()))
         return false;
-    const QString& otherStr = static_cast<const InsTextCmd*>(other)->_str;
+    const QString &otherStr = static_cast<const InsTextCmd *>(other)->_str;
 
-    if (otherStr.isEmpty() || _str.isEmpty()) //just a precaution
+    if (otherStr.isEmpty() || _str.isEmpty()) // just a precaution
         return false;
 
-    //be close to behaviour of LibreOffice
+    // be close to behaviour of LibreOffice
     if (!_str.at(_str.size() - 1).isSpace() && otherStr.at(0).isSpace())
         return false;
 
@@ -105,8 +103,9 @@ bool InsTextCmd::mergeWith(const QUndoCommand *other)
 
 void InsTextCmd::doRedo()
 {
-    Catalog& catalog = *_catalog;
-    DocPosition pos = _pos; pos.offset += _str.size();
+    Catalog &catalog = *_catalog;
+    DocPosition pos = _pos;
+    pos.offset += _str.size();
     catalog.setLastModifiedPos(pos);
     catalog.targetInsert(_pos, _str);
 }
@@ -115,34 +114,30 @@ void InsTextCmd::doUndo()
 {
     _catalog->targetDelete(_pos, _str.size());
 }
-//END InsTextCmd
+// END InsTextCmd
 
-
-//BEGIN DelTextCmd
+// BEGIN DelTextCmd
 DelTextCmd::DelTextCmd(Catalog *catalog, const DocPosition &pos, const QString &str)
     : LokalizeTargetCmd(catalog, pos, i18nc("@item Undo action item", "Deletion"))
     , _str(str)
-{}
+{
+}
 
 bool DelTextCmd::mergeWith(const QUndoCommand *other)
 {
-    const DocPosition otherPos = static_cast<const LokalizeUnitCmd*>(other)->pos();
-    if (
-        (other->id() != id())
-        || (otherPos.entry != _pos.entry)
-        || (otherPos.form != _pos.form)
-    )
+    const DocPosition otherPos = static_cast<const LokalizeUnitCmd *>(other)->pos();
+    if ((other->id() != id()) || (otherPos.entry != _pos.entry) || (otherPos.form != _pos.form))
         return false;
 
-    //Delete
+    // Delete
     if (otherPos.offset == _pos.offset) {
-        _str += static_cast<const DelTextCmd*>(other)->_str;
+        _str += static_cast<const DelTextCmd *>(other)->_str;
         return true;
     }
 
-    //BackSpace
-    if (otherPos.offset == _pos.offset - static_cast<const DelTextCmd*>(other)->_str.size()) {
-        _str.prepend(static_cast<const DelTextCmd*>(other)->_str);
+    // BackSpace
+    if (otherPos.offset == _pos.offset - static_cast<const DelTextCmd *>(other)->_str.size()) {
+        _str.prepend(static_cast<const DelTextCmd *>(other)->_str);
         _pos.offset = otherPos.offset;
         return true;
     }
@@ -155,27 +150,27 @@ void DelTextCmd::doRedo()
 }
 void DelTextCmd::doUndo()
 {
-    //DocPosition pos=_pos; //pos.offset+=_str.size();
+    // DocPosition pos=_pos; //pos.offset+=_str.size();
     //_catalog.setLastModifiedPos(pos);
     _catalog->targetInsert(_pos, _str);
 }
-//END DelTextCmd
+// END DelTextCmd
 
-
-//BEGIN SetStateCmd
-void SetStateCmd::push(Catalog *catalog, const DocPosition& pos, bool approved)
+// BEGIN SetStateCmd
+void SetStateCmd::push(Catalog *catalog, const DocPosition &pos, bool approved)
 {
     catalog->push(new SetStateCmd(catalog, pos, closestState(approved, catalog->activePhaseRole())));
 }
-void SetStateCmd::instantiateAndPush(Catalog *catalog, const DocPosition& pos, TargetState state)
+void SetStateCmd::instantiateAndPush(Catalog *catalog, const DocPosition &pos, TargetState state)
 {
     catalog->push(new SetStateCmd(catalog, pos, state));
 }
 
-SetStateCmd::SetStateCmd(Catalog *catalog, const DocPosition& pos, TargetState state)
+SetStateCmd::SetStateCmd(Catalog *catalog, const DocPosition &pos, TargetState state)
     : LokalizeUnitCmd(catalog, pos, i18nc("@item Undo action item", "Approvement toggling"))
     , _state(state)
-{}
+{
+}
 
 void SetStateCmd::doRedo()
 {
@@ -186,11 +181,10 @@ void SetStateCmd::doUndo()
 {
     _catalog->setState(_pos, _prevState);
 }
-//END SetStateCmd
+// END SetStateCmd
 
-
-//BEGIN InsTagCmd
-InsTagCmd::InsTagCmd(Catalog *catalog, const DocPosition& pos, const InlineTag& tag)
+// BEGIN InsTagCmd
+InsTagCmd::InsTagCmd(Catalog *catalog, const DocPosition &pos, const InlineTag &tag)
     : LokalizeTargetCmd(catalog, pos, i18nc("@item Undo action item", "Markup Insertion"))
     , _tag(tag)
 {
@@ -199,8 +193,9 @@ InsTagCmd::InsTagCmd(Catalog *catalog, const DocPosition& pos, const InlineTag&
 
 void InsTagCmd::doRedo()
 {
-    Catalog& catalog = *_catalog;
-    DocPosition pos = _pos; pos.offset++; //between paired tags or after single tag
+    Catalog &catalog = *_catalog;
+    DocPosition pos = _pos;
+    pos.offset++; // between paired tags or after single tag
     catalog.setLastModifiedPos(pos);
     catalog.targetInsertTag(_pos, _tag);
 }
@@ -209,12 +204,13 @@ void InsTagCmd::doUndo()
 {
     _catalog->targetDeleteTag(_pos);
 }
-//END InsTagCmd
+// END InsTagCmd
 
-//BEGIN DelTagCmd
-DelTagCmd::DelTagCmd(Catalog *catalog, const DocPosition& pos)
+// BEGIN DelTagCmd
+DelTagCmd::DelTagCmd(Catalog *catalog, const DocPosition &pos)
     : LokalizeTargetCmd(catalog, pos, i18nc("@item Undo action item", "Markup Deletion"))
-{}
+{
+}
 
 void DelTagCmd::doRedo()
 {
@@ -224,27 +220,28 @@ void DelTagCmd::doRedo()
 
 void DelTagCmd::doUndo()
 {
-    Catalog& catalog = *_catalog;
-    DocPosition pos = _pos; pos.offset++; //between paired tags or after single tag
+    Catalog &catalog = *_catalog;
+    DocPosition pos = _pos;
+    pos.offset++; // between paired tags or after single tag
     catalog.setLastModifiedPos(pos);
     catalog.targetInsertTag(_pos, _tag);
 }
-//END DelTagCmd
+// END DelTagCmd
 
-
-//BEGIN SetNoteCmd
-SetNoteCmd::SetNoteCmd(Catalog *catalog, const DocPosition& pos, const Note& note)
+// BEGIN SetNoteCmd
+SetNoteCmd::SetNoteCmd(Catalog *catalog, const DocPosition &pos, const Note &note)
     : LokalizeUnitCmd(catalog, pos, i18nc("@item Undo action item", "Note setting"))
     , _note(note)
 {
     _pos.part = DocPosition::Comment;
 }
 
-static void setNote(Catalog& catalog, DocPosition& _pos, const Note& note, Note& resultNote)
+static void setNote(Catalog &catalog, DocPosition &_pos, const Note &note, Note &resultNote)
 {
     resultNote = catalog.setNote(_pos, note);
     int size = catalog.notes(_pos).size();
-    if (_pos.form >= size) _pos.form = -1;
+    if (_pos.form >= size)
+        _pos.form = -1;
 }
 
 void SetNoteCmd::doRedo()
@@ -254,7 +251,8 @@ void SetNoteCmd::doRedo()
 
 void SetNoteCmd::doUndo()
 {
-    Note tmp; setNote(*_catalog, _pos, _prevNote, tmp);
+    Note tmp;
+    setNote(*_catalog, _pos, _prevNote, tmp);
 }
 
 void SetNoteCmd::setJumpingPos()
@@ -263,14 +261,15 @@ void SetNoteCmd::setJumpingPos()
     pos.form = 0;
     _catalog->setLastModifiedPos(pos);
 }
-//END SetNoteCmd
+// END SetNoteCmd
 
-//BEGIN UpdatePhaseCmd
-UpdatePhaseCmd::UpdatePhaseCmd(Catalog *catalog, const Phase& phase)
+// BEGIN UpdatePhaseCmd
+UpdatePhaseCmd::UpdatePhaseCmd(Catalog *catalog, const Phase &phase)
     : QUndoCommand(i18nc("@item Undo action item", "Update/add workflow phase"))
     , _catalog(catalog)
     , _phase(phase)
-{}
+{
+}
 
 void UpdatePhaseCmd::redo()
 {
@@ -281,16 +280,14 @@ void UpdatePhaseCmd::undo()
 {
     _catalog->updatePhase(_prevPhase);
 }
-//END UpdatePhaseCmd
+// END UpdatePhaseCmd
 
-
-
-
-//BEGIN SetEquivTransCmd
-SetEquivTransCmd::SetEquivTransCmd(Catalog *catalog, const DocPosition& pos, bool equivTrans)
+// BEGIN SetEquivTransCmd
+SetEquivTransCmd::SetEquivTransCmd(Catalog *catalog, const DocPosition &pos, bool equivTrans)
     : LokalizeTargetCmd(catalog, pos, i18nc("@item Undo action item", "Translation Equivalence Setting"))
     , _equivTrans(equivTrans)
-{}
+{
+}
 
 void SetEquivTransCmd::doRedo()
 {
@@ -301,18 +298,9 @@ void SetEquivTransCmd::doUndo()
 {
     _catalog->setEquivTrans(_pos, !_equivTrans);
 }
-//END SetEquivTransCmd
+// END SetEquivTransCmd
 
-
-
-
-
-
-bool fillTagPlaces(QMap<int, int>& tagPlaces,
-                   const CatalogString& catalogString,
-                   int start,
-                   int len
-                  )
+bool fillTagPlaces(QMap<int, int> &tagPlaces, const CatalogString &catalogString, int start, int len)
 {
     QString target = catalogString.string;
     if (len == -1)
@@ -322,14 +310,12 @@ bool fillTagPlaces(QMap<int, int>& tagPlaces,
     while ((t = target.indexOf(TAGRANGE_IMAGE_SYMBOL, t)) != -1 && t < (start + len))
         tagPlaces[t++] = 0;
 
-
     int i = catalogString.tags.size();
     while (--i >= 0) {
-        //qCWarning(LOKALIZE_LOG)<<catalogString.ranges.at(i).getElementName();
-        const InlineTag& tag = catalogString.tags.at(i);
-        if (tagPlaces.contains(tag.start)
-            && tagPlaces.contains(tag.end)) {
-            //qCWarning(LOKALIZE_LOG)<<"start"<<catalogString.ranges.at(i).start<<"end"<<catalogString.ranges.at(i).end;
+        // qCWarning(LOKALIZE_LOG)<<catalogString.ranges.at(i).getElementName();
+        const InlineTag &tag = catalogString.tags.at(i);
+        if (tagPlaces.contains(tag.start) && tagPlaces.contains(tag.end)) {
+            // qCWarning(LOKALIZE_LOG)<<"start"<<catalogString.ranges.at(i).start<<"end"<<catalogString.ranges.at(i).end;
             tagPlaces[tag.end] = 2;
             tagPlaces[tag.start] = 1;
         }
@@ -342,7 +328,7 @@ bool fillTagPlaces(QMap<int, int>& tagPlaces,
     return it == tagPlaces.constEnd();
 }
 
-bool removeTargetSubstring(Catalog* catalog, DocPosition pos, int delStart, int delLen)
+bool removeTargetSubstring(Catalog *catalog, DocPosition pos, int delStart, int delLen)
 {
     CatalogString targetWithTags = catalog->targetWithTags(pos);
     QString target = targetWithTags.string;
@@ -350,7 +336,7 @@ bool removeTargetSubstring(Catalog* catalog, DocPosition pos, int delStart, int
     if (delLen == -1)
         delLen = target.length() - delStart;
 
-    bool doTags = catalog->capabilities()&Tags;
+    bool doTags = catalog->capabilities() & Tags;
     QMap<int, int> tagPlaces;
     if (target.isEmpty() || (doTags && !fillTagPlaces(tagPlaces, targetWithTags, delStart, delLen))) {
         qCWarning(LOKALIZE_LOG) << "error removing text" << target;
@@ -359,23 +345,24 @@ bool removeTargetSubstring(Catalog* catalog, DocPosition pos, int delStart, int
 
     catalog->beginMacro(i18nc("@item Undo action item", "Remove text with markup"));
 
-    //all indexes are ok (or target is just plain text)
-    //modified=true;
-    //qCWarning(LOKALIZE_LOG)<<"all indexes are ok";
+    // all indexes are ok (or target is just plain text)
+    // modified=true;
+    // qCWarning(LOKALIZE_LOG)<<"all indexes are ok";
     QMapIterator<int, int> it(tagPlaces);
     it.toBack();
     while (it.hasPrevious()) {
         it.previous();
-        if (it.value() != 1) continue;
+        if (it.value() != 1)
+            continue;
         pos.offset = it.key();
-        DelTagCmd* cmd = new DelTagCmd(catalog, pos);
+        DelTagCmd *cmd = new DelTagCmd(catalog, pos);
         catalog->push(cmd);
         delLen -= 1 + cmd->tag().isPaired();
         QString tmp = catalog->targetWithTags(pos).string;
         tmp.replace(TAGRANGE_IMAGE_SYMBOL, u'*');
         qCDebug(LOKALIZE_LOG) << "\tdeleting at" << it.key() << "current string:" << tmp << "delLen" << delLen;
     }
-    //charsRemoved-=lenDecrement;
+    // charsRemoved-=lenDecrement;
     QString tmp = catalog->targetWithTags(pos).string;
     tmp.replace(TAGRANGE_IMAGE_SYMBOL, u'*');
     qCDebug(LOKALIZE_LOG) << "offset" << delStart << delLen << "current string:" << tmp;
@@ -395,45 +382,45 @@ bool removeTargetSubstring(Catalog* catalog, DocPosition pos, int delStart, int
     return true;
 }
 
-
-void insertCatalogString(Catalog* catalog, DocPosition pos, const CatalogString& catStr, int start)
+void insertCatalogString(Catalog *catalog, DocPosition pos, const CatalogString &catStr, int start)
 {
     QMap<int, int> posToTag;
     int i = catStr.tags.size();
     bool containsMarkup = i;
     while (--i >= 0) {
-        const InlineTag& tag = catStr.tags.at(i);
-        //qCWarning(LOKALIZE_LOG)<<"\t"<<catStr.tags.at(i).getElementName()<<catStr.tags.at(i).id<<catStr.tags.at(i).start<<catStr.tags.at(i).end;
-        //qCWarning(LOKALIZE_LOG)<<"\ttag"<<catStr.tags.at(i).start<<catStr.tags.at(i).end;
+        const InlineTag &tag = catStr.tags.at(i);
+        // qCWarning(LOKALIZE_LOG)<<"\t"<<catStr.tags.at(i).getElementName()<<catStr.tags.at(i).id<<catStr.tags.at(i).start<<catStr.tags.at(i).end;
+        // qCWarning(LOKALIZE_LOG)<<"\ttag"<<catStr.tags.at(i).start<<catStr.tags.at(i).end;
         posToTag.insert(tag.start, i);
         posToTag.insert(tag.end, i);
     }
 
-    if (containsMarkup) catalog->beginMacro(i18nc("@item Undo action item", "Insert text with markup"));
+    if (containsMarkup)
+        catalog->beginMacro(i18nc("@item Undo action item", "Insert text with markup"));
 
     i = 0;
     int prev = 0;
     while ((i = catStr.string.indexOf(TAGRANGE_IMAGE_SYMBOL, i)) != -1) {
         qCDebug(LOKALIZE_LOG) << "TAGRANGE_IMAGE_SYMBOL" << i;
-        //text that was before tag we found
+        // text that was before tag we found
         if (i - prev) {
             pos.offset = start + prev;
             catalog->push(new InsTextCmd(catalog, pos, catStr.string.mid(prev, i - prev)));
         }
 
-        //now dealing with tag
+        // now dealing with tag
         qCDebug(LOKALIZE_LOG) << "posToTag.value(i)" << posToTag.value(i) << catStr.tags.size();
         if (posToTag.value(i) < catStr.tags.size()) {
             InlineTag tag = catStr.tags.at(posToTag.value(i));
             qCDebug(LOKALIZE_LOG) << i << "testing for tag" << tag.name() << tag.start << tag.start;
-            if (tag.start == i) { //this is an opening tag (may be single tag)
+            if (tag.start == i) { // this is an opening tag (may be single tag)
                 pos.offset = start + i;
                 tag.start += start;
                 tag.end += start;
                 catalog->push(new InsTagCmd(catalog, pos, tag));
             }
         } else {
-            //HACK to keep positions in sync
+            // HACK to keep positions in sync
             pos.offset = start + i;
             catalog->push(new InsTextCmd(catalog, pos, QStringLiteral(" ")));
         }
@@ -442,7 +429,6 @@ void insertCatalogString(Catalog* catalog, DocPosition pos, const CatalogString&
     pos.offset = start + prev;
     if (catStr.string.length() - prev > 0)
         catalog->push(new InsTextCmd(catalog, pos, catStr.string.mid(prev)));
-    if (containsMarkup) catalog->endMacro();
+    if (containsMarkup)
+        catalog->endMacro();
 }
-
-
