@@ -13,30 +13,26 @@
 
 #include "gettextimport.h"
 
-#include "lokalize_debug.h"
+// #include <resources.h>
 
-//#include <resources.h>
-
-#include <QFile>
-#include <QTime>
-#include <QFileInfo>
-#include <QRegularExpression>
-#include <QList>
-#include <QTextStream>
 #include <QEventLoop>
+#include <QFile>
+#include <QFileInfo>
+#include <QList>
+#include <QTime>
 
 #include "catalogitem.h"
 
 using namespace GettextCatalog;
 
-ConversionStatus GettextImportPlugin::load(QIODevice* device)
+ConversionStatus GettextImportPlugin::load(QIODevice *device)
 {
     _testBorked = false;
     _errorLine = 0;
 
     // find codec for file
     //    bool hadCodec;
-    const auto codecName = codecForDevice(device/*, &hadCodec*/);
+    const auto codecName = codecForDevice(device /*, &hadCodec*/);
     QTextStream stream(device);
     stream.seek(0);
 
@@ -52,15 +48,15 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
         stream.setString(&decodedData, QIODevice::ReadOnly);
     }
 
-    //QIODevice *dev = stream.device();
-    //int fileSize = dev->size();
+    // QIODevice *dev = stream.device();
+    // int fileSize = dev->size();
 
     // if somethings goes wrong with the parsing, we don't have deleted the old contents
     CatalogItem tempHeader;
 
-    //qCDebug(LOKALIZE_LOG) << "start parsing...";
-//     QTime aaa;
-//     aaa.start();
+    // qCDebug(LOKALIZE_LOG) << "start parsing...";
+    //     QTime aaa;
+    //     aaa.start();
     // first read header
     const ConversionStatus status = readEntry(stream);
 
@@ -74,16 +70,16 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
     }
 
     bool reconstructedHeader = !_msgid.isEmpty() && !_msgid.first().isEmpty();
-    //qCWarning(LOKALIZE_LOG) << "HEADER MSGID: " << _msgid;
-    //qCWarning(LOKALIZE_LOG) << "HEADER MSGSTR: " << _msgstr;
+    // qCWarning(LOKALIZE_LOG) << "HEADER MSGID: " << _msgid;
+    // qCWarning(LOKALIZE_LOG) << "HEADER MSGSTR: " << _msgstr;
     if (Q_UNLIKELY(reconstructedHeader)) {
         // The header must have an empty msgid
         qCWarning(LOKALIZE_LOG) << "Header entry has non-empty msgid. Creating a temporary header! " << _msgid;
         tempHeader.setMsgid(QString());
         QString tmp(
             QStringLiteral("Content-Type: text/plain; charset=UTF-8\\n" // Unknown charset
-            "Content-Transfer-Encoding: 8bit\\n"
-            "Mime-Version: 1.0"));
+                           "Content-Transfer-Encoding: 8bit\\n"
+                           "Mime-Version: 1.0"));
         tempHeader.setMsgstr(tmp);
         // We keep the comment of the first entry, as it might really be a header comment (at least partially)
         const QString comment(QStringLiteral("# Header entry was created by Lokalize.\n#\n") + _comment);
@@ -94,24 +90,18 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
         tempHeader.setMsgstr(_msgstr);
         tempHeader.setComment(_comment);
     }
-//    if(tempHeader.isFuzzy())
-//    {
-//       tempHeader.removeFuzzy();
-//    }
+    //    if(tempHeader.isFuzzy())
+    //    {
+    //       tempHeader.removeFuzzy();
+    //    }
 
     // check if header seems to indicate docbook content generated by xml2pot
     const bool docbookContent = tempHeader.msgstr().contains(QStringLiteral("application/x-xml2pot"));
 
-
-
-
-
-
-
     // now parse the rest of the file
     uint counter = 0;
     QList<int> errorIndex;
-    //bool recoveredError=false;
+    // bool recoveredError=false;
     bool docbookFile = false;
 
     ExtraDataSaver _extraDataSaver;
@@ -130,7 +120,8 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
                 tempCatItem.setPlural(_gettextPluralForm);
                 tempCatItem.setMsgid(_msgid, _msgidMultiline);
                 tempCatItem.setMsgstr(_msgstr, _msgstrMultiline);
-                if (_msgctxtPresent) tempCatItem.setMsgctxt(_msgctxt);
+                if (_msgctxtPresent)
+                    tempCatItem.setMsgctxt(_msgctxt);
                 tempCatItem.setComment(_comment);
 
                 // add new entry to the list of entries
@@ -141,17 +132,17 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
             }
         } else if (Q_UNLIKELY(success == RECOVERED_PARSE_ERROR)) {
             qCDebug(LOKALIZE_LOG) << "Recovered parse error in entry: " << counter;
-            //recoveredError=true;
+            // recoveredError=true;
             errorIndex.append(counter);
 
             CatalogItem tempCatItem;
             tempCatItem.setPlural(_gettextPluralForm);
             tempCatItem.setMsgid(_msgid);
             tempCatItem.setMsgstr(_msgstr);
-            if (_msgctxtPresent) tempCatItem.setMsgctxt(_msgctxt);
+            if (_msgctxtPresent)
+                tempCatItem.setMsgctxt(_msgctxt);
             tempCatItem.setComment(_comment);
 
-
             // add new entry to the list of entries
             appendCatalogItem(tempCatItem);
         } else if (success == PARSE_ERROR) {
@@ -162,7 +153,6 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
             return PARSE_ERROR;
         }
         counter++;
-
     }
 
     // TODO: can we check that there is no useful entry?
@@ -172,18 +162,18 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
         return PARSE_ERROR;
     }
 
-    //qCDebug(LOKALIZE_LOG) << " ready";
+    // qCDebug(LOKALIZE_LOG) << " ready";
 
     // We have successfully loaded the file (perhaps with recovered errors)
 
-//    qCWarning(LOKALIZE_LOG) << " done in " << aaa.elapsed() <<_extraDataSaver->extraData.size() << endl;
+    //    qCWarning(LOKALIZE_LOG) << " done in " << aaa.elapsed() <<_extraDataSaver->extraData.size() << endl;
 
     setGeneratedFromDocbook(docbookContent || docbookFile);
     setHeader(tempHeader);
     setCatalogExtraData(_extraDataSaver.extraData);
     setErrorIndex(errorIndex);
     setCodec(codecName);
-    //setMimeTypes( "text/x-gettext-translation" );
+    // setMimeTypes( "text/x-gettext-translation" );
 #if 0
     if (Q_UNLIKELY(recoveredErrorInHeader)) {
         qCDebug(LOKALIZE_LOG) << " Returning: header error";
@@ -194,18 +184,18 @@ ConversionStatus GettextImportPlugin::load(QIODevice* device)
     } else
 #endif
     {
-        //qCDebug(LOKALIZE_LOG) << " Returning: OK! :-)";
+        // qCDebug(LOKALIZE_LOG) << " Returning: OK! :-)";
         return OK;
     }
 }
 
-QByteArray GettextImportPlugin::codecForDevice(QIODevice* device/*, bool* hadCodec*/)
+QByteArray GettextImportPlugin::codecForDevice(QIODevice *device /*, bool* hadCodec*/)
 {
     QTextStream stream(device);
     stream.seek(0);
     _errorLine = 0;
     stream.setEncoding(QStringConverter::Utf8);
-    stream.setAutoDetectUnicode(true); //this way we can detect UTF-16
+    stream.setAutoDetectUnicode(true); // this way we can detect UTF-16
 
     ConversionStatus status = readEntry(stream);
     if (Q_UNLIKELY(status != OK && status != RECOVERED_PARSE_ERROR)) {
@@ -221,7 +211,8 @@ QByteArray GettextImportPlugin::codecForDevice(QIODevice* device/*, bool* hadCod
     }
 
     const QString charset = match.captured(1);
-    if (charset != QLatin1String("UTF-8")) qCDebug(LOKALIZE_LOG) << "charset:" << charset;
+    if (charset != QLatin1String("UTF-8"))
+        qCDebug(LOKALIZE_LOG) << "charset:" << charset;
 
     if (charset.isEmpty()) {
         qCWarning(LOKALIZE_LOG) << "No charset defined! Assuming UTF-8!";
@@ -244,7 +235,7 @@ QByteArray GettextImportPlugin::codecForDevice(QIODevice* device/*, bool* hadCod
     return QStringConverter::nameForEncoding(stream.encoding());
 }
 
-ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
+ConversionStatus GettextImportPlugin::readEntry(QTextStream &stream)
 {
     ConversionStatus result = readEntryRaw(stream);
     const QString FROM = QStringLiteral("\\\"");
@@ -255,14 +246,20 @@ ConversionStatus GettextImportPlugin::readEntry(QTextStream& stream)
     return result;
 }
 
-ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
+ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream &stream)
 {
-    //qCDebug(LOKALIZE_LOG) << " START";
-    enum {Begin, Comment, Msgctxt, Msgid, Msgstr} part = Begin;
+    // qCDebug(LOKALIZE_LOG) << " START";
+    enum {
+        Begin,
+        Comment,
+        Msgctxt,
+        Msgid,
+        Msgstr,
+    } part = Begin;
 
     bool error = false;
     bool recoverableError = false;
-    //bool seenMsgctxt=false;
+    // bool seenMsgctxt=false;
     _msgstr.clear();
     _msgstr.append(QString());
     _msgid.clear();
@@ -278,7 +275,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
 
     while (!stream.atEnd()) {
         _errorLine++;
-        //line=stream.readLine();
+        // line=stream.readLine();
         if (!_bufferedLine.isEmpty()) {
             line = _bufferedLine;
             _bufferedLine.clear();
@@ -301,7 +298,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
         // remember wrapping state to save file nicely
         int len = line.length();
         if (len && _maxLineLength < len && line.at(0) != QLatin1Char('#'))
-                _maxLineLength = len;
+            _maxLineLength = len;
 
         if (part == Begin) {
             // ignore trailing newlines
@@ -323,7 +320,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 line.remove(_rxMsgLineRemEndQuote);
                 _msgctxt = line;
                 _msgctxtPresent = true;
-                //seenMsgctxt=true;
+                // seenMsgctxt=true;
             } else if (line.contains(_rxMsgId)) {
                 part = Msgid;
 
@@ -354,8 +351,10 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 break;
             }
         } else if (part == Comment) {
-            if (!len && _obsolete) return OK;
-            if (!len) continue;
+            if (!len && _obsolete)
+                return OK;
+            if (!len)
+                continue;
             else if (line.startsWith(_obsoleteStart)) {
                 _comment += (QLatin1Char('\n') + line);
                 _obsolete = true;
@@ -369,7 +368,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 line.remove(_rxMsgLineRemEndQuote);
                 _msgctxt = line;
                 _msgctxtPresent = true;
-                //seenMsgctxt=true;
+                // seenMsgctxt=true;
             } else if (line.contains(_rxMsgId)) {
                 part = Msgid;
 
@@ -381,7 +380,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 (*(_msgid).begin()) = line;
             }
             // one of the quotation marks is missing
-            else if (Q_UNLIKELY(/*_testBorked&&*/line.contains(_rxMsgIdBorked))) {
+            else if (Q_UNLIKELY(/*_testBorked&&*/ line.contains(_rxMsgIdBorked))) {
                 part = Msgid;
 
                 // remove quotes at beginning and the end of the lines
@@ -513,7 +512,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
 
                 _msgstrMultiline = line.isEmpty();
                 (*msgstrIt) = line;
-            } else if (Q_UNLIKELY(/*_testBorked&&*/ _gettextPluralForm &&  line.contains(_rxMsgStrPluralStartBorked))) {
+            } else if (Q_UNLIKELY(/*_testBorked&&*/ _gettextPluralForm && line.contains(_rxMsgStrPluralStartBorked))) {
                 part = Msgstr;
 
                 // remove quotes at beginning and the end of the lines
@@ -536,7 +535,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 break;
             }
             // a line of the msgid with a missing quotation mark
-            else if (Q_UNLIKELY(/*_testBorked&&*/line.contains(_rxMsgLineBorked))) {
+            else if (Q_UNLIKELY(/*_testBorked&&*/ line.contains(_rxMsgLineBorked))) {
                 recoverableError = true;
 
                 // remove quotes at beginning and the end of the lines
@@ -601,7 +600,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
                 break;
             }
             // another line of the msgstr with a missing quotation mark
-            else if (Q_UNLIKELY(/*_testBorked&&*/line.contains(_rxMsgLineBorked))) {
+            else if (Q_UNLIKELY(/*_testBorked&&*/ line.contains(_rxMsgLineBorked))) {
                 recoverableError = true;
 
                 // remove quotes at beginning and the end of the lines
@@ -635,7 +634,7 @@ ConversionStatus GettextImportPlugin::readEntryRaw(QTextStream& stream)
        }
       */
 
-    //qCDebug(LOKALIZE_LOG) << " NEAR RETURN";
+    // qCDebug(LOKALIZE_LOG) << " NEAR RETURN";
     if (Q_UNLIKELY(error))
         return PARSE_ERROR;
     else if (Q_UNLIKELY(recoverableError))
