@@ -1389,7 +1389,7 @@ void EditorTab::displayWordCount()
     int sourceCount = 0;
     int targetCount = 0;
     const QRegularExpression rxClean(Project::instance()->markup() + QLatin1Char('|') + Project::instance()->accel()); // cleaning regexp; NOTE isEmpty()?
-    const QRegularExpression rxSplit(QStringLiteral("\\W|\\d")); // splitting regexp
+    const QRegularExpression rxSplit(QStringLiteral("\\W|\\d"), QRegularExpression::UseUnicodePropertiesOption); // splitting regexp
     DocPosition pos(0);
     do {
         QString msg = m_catalog->source(pos);
