@@ -14,13 +14,13 @@
 #include <config.h>
 #endif
 
-#include "pos.h"
 #include "lokalizesubwindowbase.h"
+#include "pos.h"
 
-#include <QHash>
-#include <QMdiSubWindow>
-#include <QMap>
 #include <KProcess>
+#include <QHash>
+#include <QMap>
+#include <QMdiSubWindow>
 
 namespace Sonnet
 {
@@ -50,22 +50,29 @@ namespace GlossaryNS
 class GlossaryView;
 }
 
-
-
 struct EditorState {
 public:
-    EditorState(): entry(0) {}
-    EditorState(const EditorState& s): dockWidgets(s.dockWidgets), filePath(s.filePath), entry(0) {}
-    ~EditorState() {}
+    EditorState()
+        : entry(0)
+    {
+    }
+    EditorState(const EditorState &s)
+        : dockWidgets(s.dockWidgets)
+        , filePath(s.filePath)
+        , entry(0)
+    {
+    }
+    ~EditorState()
+    {
+    }
 
     QByteArray dockWidgets;
     QString filePath;
     QString mergeFilePath;
     int entry;
-    //int offset;
+    // int offset;
 };
 
-
 /**
  * @short Editor tab
  *
@@ -76,49 +83,52 @@ public:
  *
  * @author Nick Shaforostoff <shafff@ukr.net>
  */
-class EditorTab: public LokalizeSubwindowBase2
+class EditorTab : public LokalizeSubwindowBase2
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.Lokalize.Editor")
-    //qdbuscpp2xml -m -s editortab.h -o org.kde.lokalize.Editor.xml
+    // qdbuscpp2xml -m -s editortab.h -o org.kde.lokalize.Editor.xml
 #define qdbuscpp2xml
 
 public:
-    explicit EditorTab(QWidget* parent, bool valid = true);
+    explicit EditorTab(QWidget *parent, bool valid = true);
     ~EditorTab() override;
 
-
-    //interface for LokalizeMainWindow
+    // interface for LokalizeMainWindow
     void hideDocks() override;
     void showDocks() override;
     QString currentFilePath() override;
     void setFullPathShown(bool);
-    void setProperCaption(QString, bool); //reimpl to remove ' - Lokalize'
+    void setProperCaption(QString, bool); // reimpl to remove ' - Lokalize'
 public Q_SLOTS:
     void setProperFocus();
+
 public:
     bool queryClose() override;
     EditorState state();
-    KXMLGUIClient* guiClient() override
+    KXMLGUIClient *guiClient() override
     {
-        return (KXMLGUIClient*)this;
+        return (KXMLGUIClient *)this;
     }
     QString dbusObjectPath();
     int dbusId()
     {
         return m_dbusId;
     }
-    QObject* adaptor()
+    QObject *adaptor()
     {
         return m_adaptor;
     }
 
-    //wrapper for cmdline handling
+    // wrapper for cmdline handling
     void mergeOpen(QString mergeFilePath);
 
-    bool fileOpen(QString filePath = QString(), QString suggestedDirPath = QString(), QMap<QString, QMdiSubWindow*> openedFiles = QMap<QString, QMdiSubWindow*>(), bool silent = false);
+    bool fileOpen(QString filePath = QString(),
+                  QString suggestedDirPath = QString(),
+                  QMap<QString, QMdiSubWindow *> openedFiles = QMap<QString, QMdiSubWindow *>(),
+                  bool silent = false);
 public Q_SLOTS:
-    //for undo/redo, views
+    // for undo/redo, views
     void gotoEntry(DocPosition pos);
     void gotoEntry(DocPosition pos, int selection);
 #ifdef qdbuscpp2xml
@@ -157,14 +167,14 @@ public Q_SLOTS:
     Q_SCRIPTABLE int entryCount();
     Q_SCRIPTABLE QString entrySource(int entry, int form);
     Q_SCRIPTABLE QString entryTarget(int entry, int form);
-    Q_SCRIPTABLE void setEntryTarget(int entry, int form, const QString& content);
+    Q_SCRIPTABLE void setEntryTarget(int entry, int form, const QString &content);
     Q_SCRIPTABLE int entryPluralFormCount(int entry);
     Q_SCRIPTABLE bool entryReady(int entry);
-    Q_SCRIPTABLE void addEntryNote(int entry, const QString& note);
-    Q_SCRIPTABLE void addTemporaryEntryNote(int entry, const QString& note);
+    Q_SCRIPTABLE void addEntryNote(int entry, const QString &note);
+    Q_SCRIPTABLE void addTemporaryEntryNote(int entry, const QString &note);
 
-    Q_SCRIPTABLE void addAlternateTranslation(int entry, const QString& translation);
-    Q_SCRIPTABLE void addTemporaryAlternateTranslation(int entry, const QString& translation);
+    Q_SCRIPTABLE void addAlternateTranslation(int entry, const QString &translation);
+    Q_SCRIPTABLE void addTemporaryAlternateTranslation(int entry, const QString &translation);
 
     Q_SCRIPTABLE QString currentFile()
     {
@@ -174,15 +184,15 @@ public Q_SLOTS:
     Q_SCRIPTABLE QString sourceLangCode();
     Q_SCRIPTABLE QString targetLangCode();
 
-    Q_SCRIPTABLE void attachAlternateTranslationFile(const QString& path);
+    Q_SCRIPTABLE void attachAlternateTranslationFile(const QString &path);
     Q_SCRIPTABLE void openSyncSource(QString path)
     {
         mergeOpen(path);
     }
     Q_SCRIPTABLE void reloadFile();
 #endif
-    Q_SCRIPTABLE bool saveFile(const QString& filePath = QString());
-    Q_SCRIPTABLE bool saveFileAs(const QString& defaultPath = QString());
+    Q_SCRIPTABLE bool saveFile(const QString &filePath = QString());
+    Q_SCRIPTABLE bool saveFileAs(const QString &defaultPath = QString());
     Q_SCRIPTABLE void close()
     {
         return parent()->deleteLater();
@@ -198,7 +208,7 @@ public Q_SLOTS:
 
     Q_SCRIPTABLE void mergeIntoOpenDocument();
 
-    Q_SCRIPTABLE bool findEntryBySourceContext(const QString& source, const QString& ctxt);
+    Q_SCRIPTABLE bool findEntryBySourceContext(const QString &source, const QString &ctxt);
 
     Q_SCRIPTABLE bool isValid()
     {
@@ -210,21 +220,21 @@ public Q_SLOTS:
     }
 
 private Q_SLOTS:
-    void highlightFound(const QString &, int, int); //for find/replace
-    void highlightFound_(const QString &, int, int); //for find/replace
+    void highlightFound(const QString &, int, int); // for find/replace
+    void highlightFound_(const QString &, int, int); // for find/replace
 
     void lookupSelectionInTranslationMemory();
 
-    //statusbar indication
+    // statusbar indication
     void numberOfFuzziesChanged();
     void numberOfUntranslatedChanged();
-    //fuzzy, untr [statusbar] indication
+    // fuzzy, untr [statusbar] indication
     void msgStrChanged();
-    //modif [caption] indication
+    // modif [caption] indication
     void setModificationSign();
     void updateCaptionPath();
 
-    //gui
+    // gui
     void switchForm(int);
 
     void undo();
@@ -234,20 +244,20 @@ private Q_SLOTS:
     void find();
 
     void replace();
-    void replaceNext();//internal
-    void doReplace(const QString&, int, int, int); //internal
-    void cleanupReplace();//internal
+    void replaceNext(); // internal
+    void doReplace(const QString &, int, int, int); // internal
+    void cleanupReplace(); // internal
 
-//     void selectAll();
-//     void deselectAll();
-//     void clear();
-//     void search2msgstr();
-//     void plural2msgstr();
+    //     void selectAll();
+    //     void deselectAll();
+    //     void clear();
+    //     void search2msgstr();
+    //     void plural2msgstr();
 
     void gotoEntry();
 
     void gotoPrevFuzzyUntr();
-    bool gotoNextFuzzyUntr(const DocPosition& pos);
+    bool gotoNextFuzzyUntr(const DocPosition &pos);
     bool gotoNextFuzzyUntr();
     void gotoNextFuzzy();
     void gotoPrevFuzzy();
@@ -257,11 +267,10 @@ private Q_SLOTS:
     void toggleApprovementGotoNextFuzzyUntr();
     void setApproveActionTitle();
 
-
     void spellcheck();
     void spellcheckNext();
-    void spellcheckShow(const QString&, int);
-    void spellcheckReplace(QString, int, const QString&);
+    void spellcheckShow(const QString &, int);
+    void spellcheckReplace(QString, int, const QString &);
     void spellcheckStop();
     void spellcheckCancel();
 
@@ -278,94 +287,94 @@ private Q_SLOTS:
 
     void initLater();
     void showStatesMenu();
-    void setState(QAction*);
-    void dispatchSrcFileOpenRequest(const QString& srcPath, int line);
+    void setState(QAction *);
+    void dispatchSrcFileOpenRequest(const QString &srcPath, int line);
     void indexWordsForCompletion();
 
-    void fileAutoSaveFailedWarning(const QString&);
+    void fileAutoSaveFailedWarning(const QString &);
 
     void pologyHasFinished(int exitCode, QProcess::ExitStatus exitStatus);
 
 protected:
-    void paintEvent(QPaintEvent* event) override;
+    void paintEvent(QPaintEvent *event) override;
 
 private:
     void setupAccel();
     void setupActions();
     void setupStatusBar();
 
-    void findNext(const DocPosition& startingPos);
-    void replaceNext(const DocPosition&);
+    void findNext(const DocPosition &startingPos);
+    void replaceNext(const DocPosition &);
 
 private:
-    Project* m_project{};
-    Catalog* m_catalog{};
+    Project *m_project{};
+    Catalog *m_catalog{};
 
-    EditorView* m_view{};
-    QAction* m_approveAndGoAction{};
-    KToolBarPopupAction* m_approveAction{};
-    KToolBarPopupAction* m_stateAction{};
+    EditorView *m_view{};
+    QAction *m_approveAndGoAction{};
+    KToolBarPopupAction *m_approveAction{};
+    KToolBarPopupAction *m_stateAction{};
 
-    KProcess* m_pologyProcess{};
+    KProcess *m_pologyProcess{};
     bool m_pologyProcessInProgress{};
 
     DocPosition m_currentPos{};
-    DocPosition _searchingPos{}; //for find/replace
+    DocPosition _searchingPos{}; // for find/replace
     DocPosition _replacingPos{};
     DocPosition _spellcheckPos{};
     DocPosition _spellcheckStartPos{};
 
-    Sonnet::BackgroundChecker* m_sonnetChecker{};
-    Sonnet::Dialog* m_sonnetDialog{};
+    Sonnet::BackgroundChecker *m_sonnetChecker{};
+    Sonnet::Dialog *m_sonnetDialog{};
     int m_spellcheckStartUndoIndex{};
     bool m_spellcheckStop{};
 
-    bool m_currentIsApproved{true}; //for statusbar animation
-    bool m_currentIsUntr{true}; //for statusbar animation
+    bool m_currentIsApproved{true}; // for statusbar animation
+    bool m_currentIsUntr{true}; // for statusbar animation
 
     bool m_fullPathShown{};
 
-    bool m_doReplaceCalled{}; //used to prevent non-clean catalog status
-    KFind* m_find{};
-    KReplace* m_replace{};
+    bool m_doReplaceCalled{}; // used to prevent non-clean catalog status
+    KFind *m_find{};
+    KReplace *m_replace{};
 
-    //BEGIN views
-    MergeView* m_syncView{};
-    MergeView* m_syncViewSecondary{};
-    CatalogView* m_transUnitsView{};
-    MsgCtxtView* m_notesView{};
-    AltTransView* m_altTransView{};
-    //END views
+    // BEGIN views
+    MergeView *m_syncView{};
+    MergeView *m_syncViewSecondary{};
+    CatalogView *m_transUnitsView{};
+    MsgCtxtView *m_notesView{};
+    AltTransView *m_altTransView{};
+    // END views
 
     QString _captionPath;
 
     bool m_srcFileOpenRequestAccepted{};
 
-    //BEGIN dbus
+    // BEGIN dbus
     bool m_valid{};
-    QObject* m_adaptor{};
+    QObject *m_adaptor{};
     int m_dbusId{-1};
     static QList<int> ids;
-    //END dbus
+    // END dbus
 
 Q_SIGNALS:
-    void tmLookupRequested(DocPosition::Part, const QString&);
-    void tmLookupRequested(const QString& source, const QString& target);
+    void tmLookupRequested(DocPosition::Part, const QString &);
+    void tmLookupRequested(const QString &source, const QString &target);
 
-    Q_SCRIPTABLE void srcFileOpenRequested(const QString& srcPath, int line);
+    Q_SCRIPTABLE void srcFileOpenRequested(const QString &srcPath, int line);
 
-    void fileOpenRequested(const QString& filePath, const QString& str, const QString& ctxt, const bool setAsActive);
+    void fileOpenRequested(const QString &filePath, const QString &str, const QString &ctxt, const bool setAsActive);
 
-    //emitted when mainwindow is closed or another file is opened
+    // emitted when mainwindow is closed or another file is opened
     void fileClosed();
-    Q_SCRIPTABLE void fileClosed(const QString& path);
-    Q_SCRIPTABLE void fileSaved(const QString& path);
-    Q_SCRIPTABLE void fileAboutToBeClosed();//old catalog is still accessible
+    Q_SCRIPTABLE void fileClosed(const QString &path);
+    Q_SCRIPTABLE void fileSaved(const QString &path);
+    Q_SCRIPTABLE void fileAboutToBeClosed(); // old catalog is still accessible
     Q_SCRIPTABLE void fileOpened();
 
     Q_SCRIPTABLE void entryDisplayed();
-    void signalNewEntryDisplayed(const DocPosition&);
-    void signalEntryWithMergeDisplayed(bool, const DocPosition&);
+    void signalNewEntryDisplayed(const DocPosition &);
+    void signalEntryWithMergeDisplayed(bool, const DocPosition &);
     void signalFirstDisplayed(bool);
     void signalLastDisplayed(bool);
 
@@ -383,7 +392,7 @@ Q_SIGNALS:
     void signalNextFuzzyOrUntrAvailable(bool);
 
     // merge mode signals gone to the view
-    //NOTE move these to catalog tree view?
+    // NOTE move these to catalog tree view?
     void signalPriorBookmarkAvailable(bool);
     void signalNextBookmarkAvailable(bool);
     void signalBookmarkDisplayed(bool);
