@@ -9,63 +9,62 @@
 
 #include "lokalize_debug.h"
 
+#include "catalog.h"
+#include "cmd.h"
 #include "editortab.h"
 #include "editorview.h"
-#include "catalog.h"
 #include "pos.h"
-#include "cmd.h"
-#include "project.h"
 #include "prefs_lokalize.h"
-#include "ui_kaider_findextension.h"
+#include "project.h"
 #include "stemming.h"
+#include "ui_kaider_findextension.h"
 
 #include <kcoreaddons_version.h>
 #include <klocalizedstring.h>
 #include <kmessagebox.h>
-#include <kreplacedialog.h>
 #include <kreplace.h>
+#include <kreplacedialog.h>
 
 #include <sonnet/backgroundchecker.h>
 #include <sonnet/dialog.h>
 
-#include <QTimer>
-#include <QPointer>
 #include <QElapsedTimer>
-
+#include <QPointer>
+#include <QTimer>
 
 #define IGNOREACCELS KFind::MinimumUserOption
-#define INCLUDENOTES KFind::MinimumUserOption*2
+#define INCLUDENOTES KFind::MinimumUserOption * 2
 
-static long makeOptions(long options, const Ui_findExtension* ui_findExtension)
+static long makeOptions(long options, const Ui_findExtension *ui_findExtension)
 {
-    return options
-           + IGNOREACCELS * ui_findExtension->m_ignoreAccelMarks->isChecked()
-           + INCLUDENOTES * ui_findExtension->m_notes->isChecked();
-    //bool skipMarkup(){return ui_findExtension->m_skipTags->isChecked();}
+    return options + IGNOREACCELS * ui_findExtension->m_ignoreAccelMarks->isChecked() + INCLUDENOTES * ui_findExtension->m_notes->isChecked();
+    // bool skipMarkup(){return ui_findExtension->m_skipTags->isChecked();}
 }
 
-class EntryFindDialog: public KFindDialog
+class EntryFindDialog : public KFindDialog
 {
 public:
-    explicit EntryFindDialog(QWidget* parent);
+    explicit EntryFindDialog(QWidget *parent);
     ~EntryFindDialog();
     long options() const
     {
         return makeOptions(KFindDialog::options(), ui_findExtension);
     }
-    static EntryFindDialog* instance(QWidget* parent = nullptr);
+    static EntryFindDialog *instance(QWidget *parent = nullptr);
+
 private:
     static QPointer<EntryFindDialog> _instance;
     static void cleanup()
     {
         delete EntryFindDialog::_instance;
     }
+
 private:
-    Ui_findExtension* ui_findExtension;
+    Ui_findExtension *ui_findExtension;
 };
 
 QPointer<EntryFindDialog> EntryFindDialog::_instance = nullptr;
-EntryFindDialog* EntryFindDialog::instance(QWidget* parent)
+EntryFindDialog *EntryFindDialog::instance(QWidget *parent)
 {
     if (_instance == nullptr) {
         _instance = new EntryFindDialog(parent);
@@ -74,7 +73,7 @@ EntryFindDialog* EntryFindDialog::instance(QWidget* parent)
     return _instance;
 }
 
-EntryFindDialog::EntryFindDialog(QWidget* parent)
+EntryFindDialog::EntryFindDialog(QWidget *parent)
     : KFindDialog(parent)
     , ui_findExtension(new Ui_findExtension)
 {
@@ -97,29 +96,31 @@ EntryFindDialog::~EntryFindDialog()
     delete ui_findExtension;
 }
 
-//BEGIN EntryReplaceDialog
-class EntryReplaceDialog: public KReplaceDialog
+// BEGIN EntryReplaceDialog
+class EntryReplaceDialog : public KReplaceDialog
 {
 public:
-    explicit EntryReplaceDialog(QWidget* parent);
+    explicit EntryReplaceDialog(QWidget *parent);
     ~EntryReplaceDialog();
     long options() const
     {
         return makeOptions(KReplaceDialog::options(), ui_findExtension);
     }
-    static EntryReplaceDialog* instance(QWidget* parent = nullptr);
+    static EntryReplaceDialog *instance(QWidget *parent = nullptr);
+
 private:
     static QPointer<EntryReplaceDialog> _instance;
     static void cleanup()
     {
         delete EntryReplaceDialog::_instance;
     }
+
 private:
-    Ui_findExtension* ui_findExtension;
+    Ui_findExtension *ui_findExtension;
 };
 
 QPointer<EntryReplaceDialog> EntryReplaceDialog::_instance = nullptr;
-EntryReplaceDialog* EntryReplaceDialog::instance(QWidget* parent)
+EntryReplaceDialog *EntryReplaceDialog::instance(QWidget *parent)
 {
     if (_instance == nullptr) {
         _instance = new EntryReplaceDialog(parent);
@@ -128,12 +129,12 @@ EntryReplaceDialog* EntryReplaceDialog::instance(QWidget* parent)
     return _instance;
 }
 
-EntryReplaceDialog::EntryReplaceDialog(QWidget* parent)
+EntryReplaceDialog::EntryReplaceDialog(QWidget *parent)
     : KReplaceDialog(parent)
     , ui_findExtension(new Ui_findExtension)
 {
     ui_findExtension->setupUi(findExtension());
-    //ui_findExtension->m_notes->hide();
+    // ui_findExtension->m_notes->hide();
     setHasSelection(false);
 
     KConfig config;
@@ -153,31 +154,30 @@ EntryReplaceDialog::~EntryReplaceDialog()
 
     delete ui_findExtension;
 }
-//END EntryReplaceDialog
+// END EntryReplaceDialog
 
-//TODO &amp;, &nbsp;
-static void calcOffsetWithAccels(const QString& data, int& offset, int& length)
+// TODO &amp;, &nbsp;
+static void calcOffsetWithAccels(const QString &data, int &offset, int &length)
 {
     int i = 0;
     for (; i < offset; ++i)
         if (Q_UNLIKELY(data.at(i) == QLatin1Char('&')))
             ++offset;
 
-    //if & is inside highlighted word
+    // if & is inside highlighted word
     int limit = offset + length;
     for (i = offset; i < limit; ++i)
         if (Q_UNLIKELY(data.at(i) == QLatin1Char('&'))) {
             ++length;
-            limit = qMin(data.size(), offset + length); //just safety
+            limit = qMin(data.size(), offset + length); // just safety
         }
 }
-static bool determineStartingPos(Catalog* m_catalog, KFind* find, DocPosition& pos) //search or replace
-//called from find() and findNext()
+static bool determineStartingPos(Catalog *m_catalog, KFind *find, DocPosition &pos) // search or replace
+// called from find() and findNext()
 {
     if (find->options() & KFind::FindBackwards) {
         pos.entry = m_catalog->numberOfEntries() - 1;
-        pos.form = (m_catalog->isPlural(pos.entry)) ?
-                   m_catalog->numberOfPluralForms() - 1 : 0;
+        pos.form = (m_catalog->isPlural(pos.entry)) ? m_catalog->numberOfPluralForms() - 1 : 0;
     } else {
         pos.entry = 0;
         pos.form = 0;
@@ -187,14 +187,14 @@ static bool determineStartingPos(Catalog* m_catalog, KFind* find, DocPosition& p
 
 void EditorTab::find()
 {
-    //QWidget* p=0; QWidget* next=qobject_cast<QWidget*>(parent()); while(next) { p=next; next=qobject_cast<QWidget*>(next->parent()); }
+    // QWidget* p=0; QWidget* next=qobject_cast<QWidget*>(parent()); while(next) { p=next; next=qobject_cast<QWidget*>(next->parent()); }
     EntryFindDialog::instance(nativeParentWidget());
 
     QString sel = selectionInTarget();
     if (!(sel.isEmpty() && selectionInSource().isEmpty())) {
         if (sel.isEmpty())
             sel = selectionInSource();
-        if (m_find && m_find->options()&IGNOREACCELS)
+        if (m_find && m_find->options() & IGNOREACCELS)
             sel.remove(QLatin1Char('&'));
         EntryFindDialog::instance()->setPattern(sel);
     }
@@ -220,17 +220,16 @@ void EditorTab::find()
     else if (!determineStartingPos(m_catalog, m_find, pos))
         return;
 
-
     findNext(pos);
 }
 
-void EditorTab::findNext(const DocPosition& startingPos)
+void EditorTab::findNext(const DocPosition &startingPos)
 {
-    Catalog& catalog = *m_catalog;
-    KFind& find = *m_find;
+    Catalog &catalog = *m_catalog;
+    KFind &find = *m_find;
 
     if (Q_UNLIKELY(catalog.numberOfEntries() <= startingPos.entry))
-        return;//for the case when app wasn't able to process event before file close
+        return; // for the case when app wasn't able to process event before file close
 
     bool anotherEntry = _searchingPos.entry != m_currentPos.entry;
     _searchingPos = startingPos;
@@ -238,14 +237,12 @@ void EditorTab::findNext(const DocPosition& startingPos)
     if (anotherEntry)
         _searchingPos.offset = 0;
 
-
     //_searchingPos.part=DocPosition::Source;
-    bool ignoreaccels = m_find->options()&IGNOREACCELS;
-    bool includenotes = m_find->options()&INCLUDENOTES;
+    bool ignoreaccels = m_find->options() & IGNOREACCELS;
+    bool includenotes = m_find->options() & INCLUDENOTES;
     int switchOptions = DocPosition::Source | DocPosition::Target | (includenotes * DocPosition::Comment);
     int flag = 1;
     while (flag) {
-
         flag = 0;
         KFind::Result res = KFind::NoMatch;
         while (true) {
@@ -265,20 +262,17 @@ void EditorTab::findNext(const DocPosition& startingPos)
             }
 
             res = find.find();
-            //offset=-1;
+            // offset=-1;
             if (res != KFind::NoMatch)
                 break;
 
-            if (!(
-                    (find.options()&KFind::FindBackwards) ?
-                    switchPrev(m_catalog, _searchingPos, switchOptions) :
-                    switchNext(m_catalog, _searchingPos, switchOptions)
-                ))
+            if (!((find.options() & KFind::FindBackwards) ? switchPrev(m_catalog, _searchingPos, switchOptions)
+                                                          : switchNext(m_catalog, _searchingPos, switchOptions)))
                 break;
         }
 
         if (res == KFind::NoMatch) {
-            //file-wide search
+            // file-wide search
             if (find.shouldRestart(true, true)) {
                 flag = 1;
                 determineStartingPos(m_catalog, m_find, _searchingPos);
@@ -291,28 +285,24 @@ void EditorTab::findNext(const DocPosition& startingPos)
 void EditorTab::findNext()
 {
     if (m_find) {
-        findNext((m_currentPos.entry == _searchingPos.entry && _searchingPos.part == DocPosition::Comment) ?
-                 _searchingPos : m_currentPos);
+        findNext((m_currentPos.entry == _searchingPos.entry && _searchingPos.part == DocPosition::Comment) ? _searchingPos : m_currentPos);
     } else
         find();
-
 }
 
 void EditorTab::findPrev()
 {
-
     if (m_find) {
         m_find->setOptions(m_find->options() ^ KFind::FindBackwards);
         findNext(m_currentPos);
     } else {
         find();
     }
-
 }
 
 void EditorTab::highlightFound(const QString &, int matchingIndex, int matchedLength)
 {
-    if (m_find->options()&IGNOREACCELS && _searchingPos.part != DocPosition::Comment) {
+    if (m_find->options() & IGNOREACCELS && _searchingPos.part != DocPosition::Comment) {
         QString data = m_catalog->catalogString(_searchingPos).string;
         calcOffsetWithAccels(data, matchingIndex, matchedLength);
     }
@@ -326,7 +316,7 @@ void EditorTab::replace()
     EntryReplaceDialog::instance(nativeParentWidget());
 
     if (!m_view->selectionInTarget().isEmpty()) {
-        if (m_replace && m_replace->options()&IGNOREACCELS) {
+        if (m_replace && m_replace->options() & IGNOREACCELS) {
             QString tmp(m_view->selectionInTarget());
             tmp.remove(QLatin1Char('&'));
             EntryReplaceDialog::instance()->setPattern(tmp);
@@ -334,44 +324,46 @@ void EditorTab::replace()
             EntryReplaceDialog::instance()->setPattern(m_view->selectionInTarget());
     }
 
-
     if (EntryReplaceDialog::instance()->exec() != QDialog::Accepted)
         return;
 
-
-    if (m_replace) m_replace->deleteLater();// _replace=0;
+    if (m_replace)
+        m_replace->deleteLater(); // _replace=0;
 
     // This creates a find-next-prompt dialog if needed.
     {
-        m_replace = new KReplace(EntryReplaceDialog::instance()->pattern(), EntryReplaceDialog::instance()->replacement(), EntryReplaceDialog::instance()->options(), this, EntryReplaceDialog::instance());
+        m_replace = new KReplace(EntryReplaceDialog::instance()->pattern(),
+                                 EntryReplaceDialog::instance()->replacement(),
+                                 EntryReplaceDialog::instance()->options(),
+                                 this,
+                                 EntryReplaceDialog::instance());
         connect(m_replace, &KReplace::textFound, this, &EditorTab::highlightFound_);
         connect(m_replace, &KReplace::findNext, this, qOverload<>(&EditorTab::replaceNext));
         connect(m_replace, &KReplace::textReplaced, this, &EditorTab::doReplace);
         connect(m_replace, &KReplace::dialogClosed, this, &EditorTab::cleanupReplace);
-//         _replace->closeReplaceNextDialog();
+        //         _replace->closeReplaceNextDialog();
     }
-//     else
-//     {
-//         _replace->resetCounts();
-//         _replace->setPattern(EntryReplaceDialog::instance()->pattern());
-//         _replace->setOptions(EntryReplaceDialog::instance()->options());
-//     }
+    //     else
+    //     {
+    //         _replace->resetCounts();
+    //         _replace->setPattern(EntryReplaceDialog::instance()->pattern());
+    //         _replace->setOptions(EntryReplaceDialog::instance()->options());
+    //     }
 
-    //m_catalog->beginMacro(i18nc("@item Undo action item","Replace"));
+    // m_catalog->beginMacro(i18nc("@item Undo action item","Replace"));
     m_doReplaceCalled = false;
 
     if (m_replace->options() & KFind::FromCursor)
         replaceNext(m_currentPos);
     else {
         DocPosition pos;
-        if (!determineStartingPos(m_catalog, m_replace, pos)) return;
+        if (!determineStartingPos(m_catalog, m_replace, pos))
+            return;
         replaceNext(pos);
     }
-
 }
 
-
-void EditorTab::replaceNext(const DocPosition& startingPos)
+void EditorTab::replaceNext(const DocPosition &startingPos)
 {
     bool anotherEntry = m_currentPos.entry != _replacingPos.entry;
     _replacingPos = startingPos;
@@ -379,26 +371,26 @@ void EditorTab::replaceNext(const DocPosition& startingPos)
     if (anotherEntry)
         _replacingPos.offset = 0;
 
-
     int flag = 1;
-    bool ignoreaccels = m_replace->options()&IGNOREACCELS;
-    bool includenotes = m_replace->options()&INCLUDENOTES;
+    bool ignoreaccels = m_replace->options() & IGNOREACCELS;
+    bool includenotes = m_replace->options() & INCLUDENOTES;
     qCWarning(LOKALIZE_LOG) << "includenotes" << includenotes;
     int switchOptions = DocPosition::Target | (includenotes * DocPosition::Comment);
     while (flag) {
         flag = 0;
         KFind::Result res = KFind::NoMatch;
         while (true) {
-            if (m_replace->needData() || anotherEntry/*||m_view->m_modifiedAfterFind*/) {
+            if (m_replace->needData() || anotherEntry /*||m_view->m_modifiedAfterFind*/) {
                 anotherEntry = false;
-                //m_view->m_modifiedAfterFind=false;//NOTE TEST THIS
+                // m_view->m_modifiedAfterFind=false;//NOTE TEST THIS
 
                 QString data;
                 if (_replacingPos.part == DocPosition::Comment)
                     data = m_catalog->notes(_replacingPos).at(_replacingPos.form).content;
                 else {
                     data = m_catalog->targetWithTags(_replacingPos).string;
-                    if (ignoreaccels) data.remove(QLatin1Char('&'));
+                    if (ignoreaccels)
+                        data.remove(QLatin1Char('&'));
                 }
                 m_replace->setData(data);
             }
@@ -406,17 +398,13 @@ void EditorTab::replaceNext(const DocPosition& startingPos)
             if (res != KFind::NoMatch)
                 break;
 
-            if (!(
-                    (m_replace->options()&KFind::FindBackwards) ?
-                    switchPrev(m_catalog, _replacingPos, switchOptions) :
-                    switchNext(m_catalog, _replacingPos, switchOptions)
-                ))
+            if (!((m_replace->options() & KFind::FindBackwards) ? switchPrev(m_catalog, _replacingPos, switchOptions)
+                                                                : switchNext(m_catalog, _replacingPos, switchOptions)))
                 break;
         }
 
         if (res == KFind::NoMatch) {
-            if ((m_replace->options()&KFind::FromCursor)
-                && m_replace->shouldRestart(true)) {
+            if ((m_replace->options() & KFind::FromCursor) && m_replace->shouldRestart(true)) {
                 flag = 1;
                 determineStartingPos(m_catalog, m_replace, _replacingPos);
             } else {
@@ -446,7 +434,7 @@ void EditorTab::replaceNext()
 
 void EditorTab::highlightFound_(const QString &, int matchingIndex, int matchedLength)
 {
-    if (m_replace->options()&IGNOREACCELS) {
+    if (m_replace->options() & IGNOREACCELS) {
         QString data = m_catalog->targetWithTags(_replacingPos).string;
         calcOffsetWithAccels(data, matchingIndex, matchedLength);
     }
@@ -455,7 +443,6 @@ void EditorTab::highlightFound_(const QString &, int matchingIndex, int matchedL
     gotoEntry(_replacingPos, matchedLength);
 }
 
-
 void EditorTab::doReplace(const QString &newStr, int offset, int newLen, int remLen)
 {
     if (!m_doReplaceCalled) {
@@ -468,7 +455,7 @@ void EditorTab::doReplace(const QString &newStr, int offset, int newLen, int rem
     else {
         QString oldStr = m_catalog->target(_replacingPos);
 
-        if (m_replace->options()&IGNOREACCELS)
+        if (m_replace->options() & IGNOREACCELS)
             calcOffsetWithAccels(oldStr, offset, remLen);
 
         pos.offset = offset;
@@ -495,12 +482,12 @@ void EditorTab::spellcheck()
         connect(m_sonnetDialog, &Sonnet::Dialog::stop, this, &EditorTab::spellcheckStop);
         connect(m_sonnetDialog, &Sonnet::Dialog::cancel, this, &EditorTab::spellcheckCancel);
 
-        connect(m_sonnetDialog/*m_sonnetChecker*/, &Sonnet::Dialog::misspelling, this, &EditorTab::spellcheckShow);
-//         disconnect(/*m_sonnetDialog*/m_sonnetChecker,SIGNAL(misspelling(QString,int)),
-//             m_sonnetDialog,SLOT(slotMisspelling(QString,int)));
-//
-//     connect( d->checker, SIGNAL(misspelling(const QString&, int)),
-//              SLOT(slotMisspelling(const QString&, int)) );
+        connect(m_sonnetDialog /*m_sonnetChecker*/, &Sonnet::Dialog::misspelling, this, &EditorTab::spellcheckShow);
+        //         disconnect(/*m_sonnetDialog*/m_sonnetChecker,SIGNAL(misspelling(QString,int)),
+        //             m_sonnetDialog,SLOT(slotMisspelling(QString,int)));
+        //
+        //     connect( d->checker, SIGNAL(misspelling(const QString&, int)),
+        //              SLOT(slotMisspelling(const QString&, int)) );
     }
 
     QString text = m_catalog->msgstr(m_currentPos);
@@ -512,13 +499,11 @@ void EditorTab::spellcheck()
     _spellcheckPos = m_currentPos;
     _spellcheckStartPos = m_currentPos;
     m_spellcheckStop = false;
-    //m_catalog->beginMacro(i18n("Spellcheck"));
+    // m_catalog->beginMacro(i18n("Spellcheck"));
     m_spellcheckStartUndoIndex = m_catalog->index();
     m_sonnetDialog->show();
-
 }
 
-
 void EditorTab::spellcheckNext()
 {
     if (m_spellcheckStop)
@@ -528,14 +513,13 @@ void EditorTab::spellcheckNext()
         if (!switchNext(m_catalog, _spellcheckPos)) {
             qCDebug(LOKALIZE_LOG) << _spellcheckStartPos.entry;
             qCDebug(LOKALIZE_LOG) << _spellcheckStartPos.form;
-            bool continueFromStart =
-                    !(_spellcheckStartPos.entry == 0 && _spellcheckStartPos.form == 0)
-                    && KMessageBox::PrimaryAction == KMessageBox::questionTwoActions(
-                        this,
-                        i18n("Lokalize has reached end of document. Do you want to continue from start?"),
-                        i18nc("@title", "Spellcheck"),
-                        KStandardGuiItem::cont(),
-                        KStandardGuiItem::cancel());
+            bool continueFromStart = !(_spellcheckStartPos.entry == 0 && _spellcheckStartPos.form == 0)
+                && KMessageBox::PrimaryAction
+                    == KMessageBox::questionTwoActions(this,
+                                                       i18n("Lokalize has reached end of document. Do you want to continue from start?"),
+                                                       i18nc("@title", "Spellcheck"),
+                                                       KStandardGuiItem::cont(),
+                                                       KStandardGuiItem::cancel());
             if (continueFromStart) {
                 _spellcheckStartPos.entry = 0;
                 _spellcheckStartPos.form = 0;
@@ -563,7 +547,7 @@ void EditorTab::spellcheckCancel()
 
 void EditorTab::spellcheckShow(const QString &word, int offset)
 {
-    const Project& project = *Project::instance();
+    const Project &project = *Project::instance();
     const QString accel = project.accel();
 
     QString source = m_catalog->source(_spellcheckPos);
@@ -592,17 +576,11 @@ void EditorTab::spellcheckReplace(QString oldWord, int offset, const QString &ne
     int length = oldWord.length();
     calcOffsetWithAccels(m_catalog->target(pos), offset, length);
     pos.offset = offset;
-    if (length > oldWord.length()) //replaced word contains accel mark
+    if (length > oldWord.length()) // replaced word contains accel mark
         oldWord = m_catalog->target(pos).mid(offset, length);
 
     m_catalog->push(new DelTextCmd(m_catalog, pos, oldWord));
     m_catalog->push(new InsTextCmd(m_catalog, pos, newWord));
 
-
     gotoEntry(pos, newWord.length());
 }
-
-
-
-
-
