@@ -13,52 +13,53 @@
 
 #include "lokalize_debug.h"
 
-#include "xlifftextedit.h"
-#include "project.h"
 #include "catalog.h"
 #include "cmd.h"
-#include "prefs_lokalize.h"
 #include "prefs.h"
+#include "prefs_lokalize.h"
+#include "project.h"
+#include "xlifftextedit.h"
 
-#include <QTimer>
-#include <QMenu>
 #include <QDragEnterEvent>
+#include <QMenu>
+#include <QTimer>
 
-#include <QLabel>
 #include <QHBoxLayout>
+#include <QLabel>
 #include <QRegularExpression>
-#include <QTabBar>
 #include <QStringBuilder>
+#include <QTabBar>
 
+#include <kcolorscheme.h>
+#include <kled.h>
 #include <klocalizedstring.h>
 #include <kmessagebox.h>
-#include <kled.h>
 #include <kstandardshortcut.h>
-#include <kcolorscheme.h>
 
-//parent is set on qsplitter insertion
-LedsWidget::LedsWidget(QWidget* parent): QWidget(parent)
+// parent is set on qsplitter insertion
+LedsWidget::LedsWidget(QWidget *parent)
+    : QWidget(parent)
 {
     KColorScheme colorScheme(QPalette::Normal);
 
-    QHBoxLayout* layout = new QHBoxLayout(this);
+    QHBoxLayout *layout = new QHBoxLayout(this);
     layout->addStretch();
     layout->addWidget(new QLabel(i18nc("@label whether entry is fuzzy", "Not ready:"), this));
-    layout->addWidget(ledFuzzy = new KLed(colorScheme.foreground(KColorScheme::NeutralText).color()/*Qt::green*/, KLed::Off, KLed::Sunken, KLed::Rectangular));
+    layout->addWidget(ledFuzzy = new KLed(colorScheme.foreground(KColorScheme::NeutralText).color() /*Qt::green*/, KLed::Off, KLed::Sunken, KLed::Rectangular));
     layout->addWidget(new QLabel(i18nc("@label whether entry is untranslated", "Untranslated:"), this));
-    layout->addWidget(ledUntr = new KLed(colorScheme.foreground(KColorScheme::NegativeText).color()/*Qt::red*/, KLed::Off, KLed::Sunken, KLed::Rectangular));
+    layout->addWidget(ledUntr = new KLed(colorScheme.foreground(KColorScheme::NegativeText).color() /*Qt::red*/, KLed::Off, KLed::Sunken, KLed::Rectangular));
     layout->addSpacing(1);
     layout->addWidget(lblColumn = new QLabel(this));
     layout->addStretch();
     setMaximumHeight(minimumSizeHint().height());
 }
 
-void LedsWidget::contextMenuEvent(QContextMenuEvent* event)
+void LedsWidget::contextMenuEvent(QContextMenuEvent *event)
 {
     QMenu menu;
     menu.addAction(i18nc("@action", "Hide"));
     if (!menu.exec(event->globalPos()))
-        return; //NOTE the config doesn't seem to work
+        return; // NOTE the config doesn't seem to work
     Settings::setLeds(false);
     SettingsController::instance()->dirty = true;
     hide();
@@ -69,8 +70,7 @@ void LedsWidget::cursorPositionChanged(int column)
     lblColumn->setText(i18nc("@info:label cursor position", "Column: %1", column));
 }
 
-
-EditorView::EditorView(QWidget *parent, Catalog* catalog/*,keyEventHandler* kh*/)
+EditorView::EditorView(QWidget *parent, Catalog *catalog /*,keyEventHandler* kh*/)
     : QSplitter(Qt::Vertical, parent)
     , m_catalog(catalog)
     , m_sourceTextEdit(new TranslationUnitTextEdit(catalog, DocPosition::Source, this))
@@ -78,15 +78,15 @@ EditorView::EditorView(QWidget *parent, Catalog* catalog/*,keyEventHandler* kh*/
     , m_pluralTabBar(new QTabBar(this))
 {
     m_pluralTabBar->hide();
-    m_sourceTextEdit->setWhatsThis(i18n("<qt><p><b>Original String</b></p>\n"
-                                        "<p>This part of the window shows the original message\n"
-                                        "of the currently displayed entry.</p></qt>"));
+    m_sourceTextEdit->setWhatsThis(
+        i18n("<qt><p><b>Original String</b></p>\n"
+             "<p>This part of the window shows the original message\n"
+             "of the currently displayed entry.</p></qt>"));
     m_sourceTextEdit->viewport()->setBackgroundRole(QPalette::Window);
 
     m_sourceTextEdit->setVisualizeSeparators(Settings::self()->visualizeSeparators());
     m_targetTextEdit->setVisualizeSeparators(Settings::self()->visualizeSeparators());
 
-
     connect(m_targetTextEdit, &TranslationUnitTextEdit::contentsModified, this, &EditorView::resetFindForCurrent);
     connect(m_targetTextEdit, &TranslationUnitTextEdit::toggleApprovementRequested, this, &EditorView::toggleApprovement);
     connect(this, &EditorView::signalApprovedEntryDisplayed, m_targetTextEdit, &TranslationUnitTextEdit::reflectApprovementState);
@@ -118,7 +118,7 @@ EditorView::EditorView(QWidget *parent, Catalog* catalog/*,keyEventHandler* kh*/
     QWidget::setTabOrder(m_targetTextEdit, m_sourceTextEdit);
     QWidget::setTabOrder(m_sourceTextEdit, m_targetTextEdit);
     setFocusProxy(m_targetTextEdit);
-//     QTimer::singleShot(3000,this,SLOT(setupWhatsThis()));
+    //     QTimer::singleShot(3000,this,SLOT(setupWhatsThis()));
     settingsChanged();
 }
 
@@ -126,22 +126,21 @@ EditorView::~EditorView()
 {
 }
 
-
-void EditorView::resetFindForCurrent(const DocPosition& pos)
+void EditorView::resetFindForCurrent(const DocPosition &pos)
 {
     m_modifiedAfterFind = true;
     Q_EMIT signalChanged(pos.entry);
 }
 
-
 void EditorView::settingsChanged()
 {
-    //Settings::self()->config()->setGroup("Editor");
+    // Settings::self()->config()->setGroup("Editor");
     m_sourceTextEdit->document()->setDefaultFont(Settings::msgFont());
     m_targetTextEdit->document()->setDefaultFont(Settings::msgFont());
     m_sourceTextEdit->setVisualizeSeparators(Settings::self()->visualizeSeparators());
     m_targetTextEdit->setVisualizeSeparators(Settings::self()->visualizeSeparators());
-    if (m_leds) m_leds->setVisible(Settings::leds());
+    if (m_leds)
+        m_leds->setVisible(Settings::leds());
     else if (Settings::leds()) {
         m_leds = new LedsWidget(this);
         insertWidget(2, m_leds);
@@ -154,22 +153,21 @@ void EditorView::settingsChanged()
     }
 }
 
-
-
 void EditorView::gotoEntry()
 {
     return gotoEntry(DocPosition(), 0);
 }
-//main function in this file :)
+// main function in this file :)
 void EditorView::gotoEntry(DocPosition pos, int selection)
 {
     setUpdatesEnabled(false);
 
     bool refresh = (pos.entry == -1);
-    if (refresh) pos = m_targetTextEdit->currentPos();
-    //qCWarning(LOKALIZE_LOG)<<"refresh"<<refresh;
-    //qCWarning(LOKALIZE_LOG)<<"offset"<<pos.offset;
-    //TODO trigger refresh directly via Catalog signal
+    if (refresh)
+        pos = m_targetTextEdit->currentPos();
+    // qCWarning(LOKALIZE_LOG)<<"refresh"<<refresh;
+    // qCWarning(LOKALIZE_LOG)<<"offset"<<pos.offset;
+    // TODO trigger refresh directly via Catalog signal
 
     if (Q_UNLIKELY(m_catalog->isPlural(pos.entry))) {
         if (Q_UNLIKELY(m_catalog->numberOfPluralForms() != m_pluralTabBar->count())) {
@@ -188,30 +186,30 @@ void EditorView::gotoEntry(DocPosition pos, int selection)
     } else
         m_pluralTabBar->hide();
 
-    //bool keepCursor=DocPos(pos)==DocPos(_msgidEdit->currentPos());
+    // bool keepCursor=DocPos(pos)==DocPos(_msgidEdit->currentPos());
     bool keepCursor = false;
     CatalogString sourceWithTags = m_sourceTextEdit->showPos(pos, CatalogString(), keepCursor);
 
-    //qCWarning(LOKALIZE_LOG)<<"calling showPos";
+    // qCWarning(LOKALIZE_LOG)<<"calling showPos";
     QString targetString = m_targetTextEdit->showPos(pos, sourceWithTags, keepCursor).string;
-    //qCWarning(LOKALIZE_LOG)<<"ss"<<_msgstrEdit->textCursor().anchor()<<_msgstrEdit->textCursor().position();
+    // qCWarning(LOKALIZE_LOG)<<"ss"<<_msgstrEdit->textCursor().anchor()<<_msgstrEdit->textCursor().position();
     m_sourceTextEdit->cursorToStart();
     m_targetTextEdit->cursorToStart();
 
     bool untrans = targetString.isEmpty();
-    //qCWarning(LOKALIZE_LOG)<<"ss1"<<_msgstrEdit->textCursor().anchor()<<_msgstrEdit->textCursor().position();
+    // qCWarning(LOKALIZE_LOG)<<"ss1"<<_msgstrEdit->textCursor().anchor()<<_msgstrEdit->textCursor().position();
 
     if (pos.offset || selection) {
-        TranslationUnitTextEdit* msgEdit = (pos.part == DocPosition::Source ? m_sourceTextEdit : m_targetTextEdit);
+        TranslationUnitTextEdit *msgEdit = (pos.part == DocPosition::Source ? m_sourceTextEdit : m_targetTextEdit);
         QTextCursor t = msgEdit->textCursor();
         t.movePosition(QTextCursor::NextCharacter, QTextCursor::MoveAnchor, pos.offset);
-        //NOTE this was kinda bug due to on-the-fly msgid wordwrap
+        // NOTE this was kinda bug due to on-the-fly msgid wordwrap
         if (selection)
             t.movePosition(QTextCursor::NextCharacter, QTextCursor::KeepAnchor, selection);
         msgEdit->setTextCursor(t);
     } else if (!untrans) {
         QTextCursor t = m_targetTextEdit->textCursor();
-        //what if msg starts with a tag?
+        // what if msg starts with a tag?
         if (Q_UNLIKELY(targetString.startsWith(QLatin1Char('<')))) {
             const QRegularExpression regExp(QStringLiteral(">[^<]"));
             const auto match = regExp.match(targetString);
@@ -225,19 +223,18 @@ void EditorView::gotoEntry(DocPosition pos, int selection)
         }
         m_targetTextEdit->setTextCursor(t);
     }
-    //qCWarning(LOKALIZE_LOG)<<"set-->"<<_msgstrEdit->textCursor().anchor()<<_msgstrEdit->textCursor().position();
-    //qCWarning(LOKALIZE_LOG)<<"anchor"<<t.anchor()<<"pos"<<t.position();
+    // qCWarning(LOKALIZE_LOG)<<"set-->"<<_msgstrEdit->textCursor().anchor()<<_msgstrEdit->textCursor().position();
+    // qCWarning(LOKALIZE_LOG)<<"anchor"<<t.anchor()<<"pos"<<t.position();
     m_targetTextEdit->setFocus();
     setUpdatesEnabled(true);
 }
 
-
-//BEGIN edit actions that are easier to do in this class
+// BEGIN edit actions that are easier to do in this class
 void EditorView::unwrap()
 {
     unwrap(nullptr);
 }
-void EditorView::unwrap(TranslationUnitTextEdit* editor)
+void EditorView::unwrap(TranslationUnitTextEdit *editor)
 {
     if (!editor)
         editor = m_targetTextEdit;
@@ -253,7 +250,7 @@ void EditorView::unwrap(TranslationUnitTextEdit* editor)
         t.deleteChar();
 
     const QRegularExpression rx(QStringLiteral("[^(\\\\n)>]$"));
-    //remove '\n's skipping "\\\\n"
+    // remove '\n's skipping "\\\\n"
     while (!(t = editor->document()->find(rx, t)).isNull()) {
         t.movePosition(QTextCursor::EndOfLine);
         if (!t.atEnd())
@@ -263,22 +260,21 @@ void EditorView::unwrap(TranslationUnitTextEdit* editor)
         m_catalog->endMacro();
 }
 
-void EditorView::insertTerm(const QString& term)
+void EditorView::insertTerm(const QString &term)
 {
     m_targetTextEdit->insertPlainTextWithCursorCheck(term);
     m_targetTextEdit->setFocus();
 }
 
-
 QString EditorView::selectionInTarget() const
 {
-    //TODO remove IMAGES
+    // TODO remove IMAGES
     return m_targetTextEdit->textCursor().selectedText();
 }
 
 QString EditorView::selectionInSource() const
 {
-    //TODO remove IMAGES
+    // TODO remove IMAGES
     return m_sourceTextEdit->textCursor().selectedText();
 }
 
@@ -287,12 +283,9 @@ void EditorView::setProperFocus()
     m_targetTextEdit->setFocus();
 }
 
+// END edit actions that are easier to do in this class
 
-//END edit actions that are easier to do in this class
-
-
-
-TranslationUnitTextEdit* EditorView::viewPort()
+TranslationUnitTextEdit *EditorView::viewPort()
 {
     return m_targetTextEdit;
 }
@@ -307,7 +300,7 @@ void EditorView::toggleBookmark(bool checked)
 
 void EditorView::toggleApprovement()
 {
-    //qCWarning(LOKALIZE_LOG)<<"called";
+    // qCWarning(LOKALIZE_LOG)<<"called";
     if (Q_UNLIKELY(m_targetTextEdit->currentPos().entry == -1))
         return;
 
@@ -318,8 +311,7 @@ void EditorView::toggleApprovement()
 
 void EditorView::setState(TargetState state)
 {
-    if (Q_UNLIKELY(m_targetTextEdit->currentPos().entry == -1
-                   || m_catalog->state(m_targetTextEdit->currentPos()) == state))
+    if (Q_UNLIKELY(m_targetTextEdit->currentPos().entry == -1 || m_catalog->state(m_targetTextEdit->currentPos()) == state))
         return;
 
     SetStateCmd::instantiateAndPush(m_catalog, m_targetTextEdit->currentPos(), state);
