@@ -10,9 +10,9 @@
 #ifndef EDITORVIEW_H
 #define EDITORVIEW_H
 
+#include "catalogstring.h"
 #include "pos.h"
 #include "state.h"
-#include "catalogstring.h"
 
 #include <QSplitter>
 
@@ -35,91 +35,91 @@ class QDragEnterEvent;
  *
  * @short Main editor view: source and target textedits
  * @author Nick Shaforostoff <shafff@ukr.net>
-  */
+ */
 
-class EditorView: public QSplitter
+class EditorView : public QSplitter
 {
     Q_OBJECT
 public:
-    explicit EditorView(QWidget *, Catalog*);
-    virtual ~EditorView();
+    explicit EditorView(QWidget *, Catalog *);
+    ~EditorView() override;
 
-    QTabBar* tabBar()
+    QTabBar *tabBar()
     {
-        return m_pluralTabBar;   //to connect tabbar signals to controller (EditorWindow) slots
+        return m_pluralTabBar; // to connect tabbar signals to controller (EditorWindow) slots
     }
-    QString selectionInTarget() const;//for non-batch replace
+    QString selectionInTarget() const; // for non-batch replace
     QString selectionInSource() const;
 
-    TranslationUnitTextEdit* viewPort();
+    TranslationUnitTextEdit *viewPort();
     void setProperFocus();
 
 public Q_SLOTS:
-    void gotoEntry(DocPosition pos, int selection/*, bool updateHistory=true*/);
+    void gotoEntry(DocPosition pos, int selection /*, bool updateHistory=true*/);
     void gotoEntry();
     void toggleApprovement();
     void setState(TargetState);
     void setEquivTrans(bool);
     void settingsChanged();
-    void insertTerm(const QString&);
-    //workaround for qt ctrl+z bug
-    //Edit menu
+    void insertTerm(const QString &);
+    // workaround for qt ctrl+z bug
+    // Edit menu
     void unwrap();
-    void unwrap(TranslationUnitTextEdit* editor);
+    void unwrap(TranslationUnitTextEdit *editor);
 
     /*
         void dragEnterEvent(QDragEnterEvent* event);
         void dropEvent(QDropEvent*);
     */
 private:
-    Catalog* m_catalog{};
+    Catalog *m_catalog{};
 
-    TranslationUnitTextEdit * m_sourceTextEdit{};
-    TranslationUnitTextEdit * m_targetTextEdit{};
+    TranslationUnitTextEdit *m_sourceTextEdit{};
+    TranslationUnitTextEdit *m_targetTextEdit{};
 
-    QTabBar* m_pluralTabBar{};
-    LedsWidget* m_leds{};
+    QTabBar *m_pluralTabBar{};
+    LedsWidget *m_leds{};
 
 public:
-    bool m_modifiedAfterFind{}; //for F3-search reset
+    bool m_modifiedAfterFind{}; // for F3-search reset
 
 Q_SIGNALS:
     void signalEquivTranslatedEntryDisplayed(bool);
     void signalApprovedEntryDisplayed(bool);
-    void signalChangeStatusbar(const QString&);
-    void signalChanged(uint index); //esp for mergemode...
-    void binaryUnitSelectRequested(const QString& id);
-    void gotoEntryRequested(const DocPosition&);
-    void tmLookupRequested(DocPosition::Part, const QString&);
-    //void tmLookupRequested(const QString& source, const QString& target);
+    void signalChangeStatusbar(const QString &);
+    void signalChanged(uint index); // esp for mergemode...
+    void binaryUnitSelectRequested(const QString &id);
+    void gotoEntryRequested(const DocPosition &);
+    void tmLookupRequested(DocPosition::Part, const QString &);
+    // void tmLookupRequested(const QString& source, const QString& target);
     void findRequested();
     void findNextRequested();
     void replaceRequested();
     void doExplicitCompletion();
 
 private Q_SLOTS:
-    void resetFindForCurrent(const DocPosition& pos);
+    void resetFindForCurrent(const DocPosition &pos);
     void toggleBookmark(bool);
 };
 
-
 class KLed;
 class QLabel;
-class LedsWidget: public QWidget
+class LedsWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit LedsWidget(QWidget* parent);
+    explicit LedsWidget(QWidget *parent);
+
 private:
-    void contextMenuEvent(QContextMenuEvent* event) override;
+    void contextMenuEvent(QContextMenuEvent *event) override;
 
 public Q_SLOTS:
     void cursorPositionChanged(int column);
 
 public:
-    KLed* ledFuzzy;
-    KLed* ledUntr;
-    QLabel* lblColumn;
+    KLed *ledFuzzy;
+    KLed *ledUntr;
+    QLabel *lblColumn;
 };
 
 #endif
