@@ -9,37 +9,37 @@
 
 #include "msgctxtview.h"
 
-#include "noteeditor.h"
 #include "catalog.h"
 #include "cmd.h"
+#include "noteeditor.h"
 #include "prefs_lokalize.h"
 #include "project.h"
 
 #include "lokalize_debug.h"
 
+#include <kcombobox.h>
 #include <klocalizedstring.h>
 #include <ktextedit.h>
-#include <kcombobox.h>
 
+#include <QBoxLayout>
+#include <QDesktopServices>
+#include <QLabel>
+#include <QLineEdit>
+#include <QRegularExpression>
+#include <QStackedLayout>
+#include <QStringBuilder>
+#include <QStringListModel>
+#include <QTextBrowser>
 #include <QTime>
 #include <QTimer>
-#include <QBoxLayout>
-#include <QStackedLayout>
-#include <QLabel>
-#include <QStringListModel>
-#include <QLineEdit>
-#include <QTextBrowser>
-#include <QStringBuilder>
-#include <QDesktopServices>
-#include <QRegularExpression>
 
-MsgCtxtView::MsgCtxtView(QWidget* parent, Catalog* catalog)
-    : QDockWidget(i18nc("@title toolview name", "Unit metadata"), parent)
+MsgCtxtView::MsgCtxtView(QWidget *parent, Catalog *catalog)
+    : QDockWidget(i18nc("@title toolview name", "Unit Metadata"), parent)
     , m_browser(new QTextBrowser(this))
     , m_catalog(catalog)
 {
     setObjectName(QStringLiteral("msgCtxtView"));
-    QWidget* main = new QWidget(this);
+    QWidget *main = new QWidget(this);
     setWidget(main);
     m_stackedLayout = new QStackedLayout(main);
     m_stackedLayout->addWidget(m_browser);
@@ -63,7 +63,7 @@ void MsgCtxtView::cleanup()
     m_languageToolNotes.clear();
 }
 
-void MsgCtxtView::gotoEntry(const DocPosition& pos, int selection)
+void MsgCtxtView::gotoEntry(const DocPosition &pos, int selection)
 {
     m_entry = DocPos(pos);
     m_selection = selection;
@@ -75,19 +75,17 @@ void MsgCtxtView::gotoEntry(const DocPosition& pos, int selection)
 void MsgCtxtView::process()
 {
     if (m_catalog->numberOfEntries() <= m_entry.entry)
-        return;//because of Qt::QueuedConnection
+        return; // because of Qt::QueuedConnection
 
     if (m_stackedLayout->currentIndex())
         m_unfinishedNotes[m_prevEntry] = qMakePair(m_editor->note(), m_editor->noteIndex());
 
-
     if (m_unfinishedNotes.contains(m_entry)) {
         addNoteUI();
         m_editor->setNote(m_unfinishedNotes.value(m_entry).first, m_unfinishedNotes.value(m_entry).second);
     } else
         m_stackedLayout->setCurrentIndex(0);
 
-
     m_prevEntry = m_entry;
     m_browser->clear();
 
@@ -95,7 +93,7 @@ void MsgCtxtView::process()
         QString html = i18nc("@info notes to translation unit which expire when the catalog is closed", "<b>Temporary notes:</b>");
         html += MsgCtxtView::BR;
         const auto tempNotes = m_tempNotes.values(m_entry.entry);
-        for (const QString& note : tempNotes)
+        for (const QString &note : tempNotes)
             html += note.toHtmlEscaped() + MsgCtxtView::BR;
         html += MsgCtxtView::BR;
         m_browser->insertHtml(html.replace(QLatin1Char('\n'), MsgCtxtView::BR));
@@ -104,7 +102,7 @@ void MsgCtxtView::process()
         QString html = i18nc("@info notes generated by the pology check", "<b>Pology notes:</b>");
         html += MsgCtxtView::BR;
         const auto pologyNotes = m_pologyNotes.values(m_entry.entry);
-        for (const QString& note : pologyNotes)
+        for (const QString &note : pologyNotes)
             html += note.toHtmlEscaped() + MsgCtxtView::BR;
         html += MsgCtxtView::BR;
         m_browser->insertHtml(html.replace(QLatin1Char('\n'), MsgCtxtView::BR));
@@ -113,7 +111,7 @@ void MsgCtxtView::process()
         QString html = i18nc("@info notes generated by the languagetool check", "<b>LanguageTool notes:</b>");
         html += MsgCtxtView::BR;
         const auto languageToolNotes = m_languageToolNotes.values(m_entry.entry);
-        for (const QString& note : languageToolNotes)
+        for (const QString &note : languageToolNotes)
             html += note.toHtmlEscaped() + MsgCtxtView::BR;
         html += MsgCtxtView::BR;
         m_browser->insertHtml(html.replace(QLatin1Char('\n'), MsgCtxtView::BR));
@@ -133,14 +131,14 @@ void MsgCtxtView::process()
 
     const QVector<Note> notes = m_catalog->notes(m_entry.toDocPosition());
     m_hasErrorNotes = false;
-    for (const Note& note : notes)
+    for (const Note &note : notes)
         m_hasErrorNotes = m_hasErrorNotes || note.content.contains(QLatin1String("[ERROR]"));
 
-    int realOffset = displayNotes(m_browser, m_catalog->notes(m_entry.toDocPosition()), m_entry.form, m_catalog->capabilities()&MultipleNotes);
+    int realOffset = displayNotes(m_browser, m_catalog->notes(m_entry.toDocPosition()), m_entry.form, m_catalog->capabilities() & MultipleNotes);
 
     QString html;
     const auto developerNotes = m_catalog->developerNotes(m_entry.toDocPosition());
-    for (const Note& note : developerNotes) {
+    for (const Note &note : developerNotes) {
         html += MsgCtxtView::BR + escapeWithLinks(note.content).replace(QLatin1Char('\n'), BR);
     }
 
@@ -176,17 +174,16 @@ void MsgCtxtView::pology()
 {
     if (Settings::self()->pologyEnabled() && m_pologyProcessInProgress == 0 && QFile::exists(m_catalog->url())) {
         QString command = Settings::self()->pologyCommandEntry();
-        command = command.replace(QStringLiteral("%u"), QString::number(m_entry.entry + 1)).replace(QStringLiteral("%f"),  QStringLiteral("\"") + m_catalog->url() + QStringLiteral("\"")).replace(QStringLiteral("\n"), QStringLiteral(" "));
+        command = command.replace(QStringLiteral("%u"), QString::number(m_entry.entry + 1))
+                      .replace(QStringLiteral("%f"), QStringLiteral("\"") + m_catalog->url() + QStringLiteral("\""))
+                      .replace(QStringLiteral("\n"), QStringLiteral(" "));
         m_pologyProcess = new KProcess;
         m_pologyProcess->setShellCommand(command);
         m_pologyProcess->setOutputChannelMode(KProcess::SeparateChannels);
         m_pologyStartedReceivingOutput = false;
-        connect(m_pologyProcess, &KProcess::readyReadStandardOutput,
-                this, &MsgCtxtView::pologyReceivedStandardOutput);
-        connect(m_pologyProcess, &KProcess::readyReadStandardError,
-                this, &MsgCtxtView::pologyReceivedStandardError);
-        connect(m_pologyProcess, qOverload<int, QProcess::ExitStatus>(&KProcess::finished),
-                this, &MsgCtxtView::pologyHasFinished);
+        connect(m_pologyProcess, &KProcess::readyReadStandardOutput, this, &MsgCtxtView::pologyReceivedStandardOutput);
+        connect(m_pologyProcess, &KProcess::readyReadStandardError, this, &MsgCtxtView::pologyReceivedStandardError);
+        connect(m_pologyProcess, qOverload<int, QProcess::ExitStatus>(&KProcess::finished), this, &MsgCtxtView::pologyHasFinished);
         m_pologyData = QString();
         m_pologyProcessInProgress = m_entry.entry + 1;
         m_pologyProcess->start();
@@ -209,7 +206,6 @@ void MsgCtxtView::pologyReceivedStandardOutput()
     }
 }
 
-
 void MsgCtxtView::pologyReceivedStandardError()
 {
     if (m_pologyProcessInProgress == m_entry.entry + 1) {
@@ -248,7 +244,7 @@ void MsgCtxtView::addNoteUI()
     anchorClicked(QUrl(QStringLiteral("note:/add")));
 }
 
-void MsgCtxtView::anchorClicked(const QUrl& link)
+void MsgCtxtView::anchorClicked(const QUrl &link)
 {
     QString path = link.path().mid(1); // minus '/'
 
@@ -262,13 +258,13 @@ void MsgCtxtView::anchorClicked(const QUrl& link)
         }
         m_editor->setNoteAuthors(m_catalog->noteAuthors());
         QVector<Note> notes = m_catalog->notes(m_entry.toDocPosition());
-        int noteIndex = -1; //means add new note
+        int noteIndex = -1; // means add new note
         Note note;
         if (!path.endsWith(QLatin1String("add"))) {
             noteIndex = path.toInt();
             note = notes.at(noteIndex);
         } else if (!(capabilities & MultipleNotes) && notes.size()) {
-            noteIndex = 0; //so we don't overwrite the only possible note
+            noteIndex = 0; // so we don't overwrite the only possible note
             note = notes.first();
         }
         m_editor->setNote(note, noteIndex);
@@ -276,7 +272,7 @@ void MsgCtxtView::anchorClicked(const QUrl& link)
         m_stackedLayout->setCurrentIndex(1);
     } else if (link.scheme() == QLatin1String("src")) {
         int pos = path.lastIndexOf(QLatin1Char(':'));
-        Q_EMIT srcFileOpenRequested(path.left(pos), path.midRef(pos + 1).toInt());
+        Q_EMIT srcFileOpenRequested(path.left(pos), QStringView(path).mid(pos + 1).toInt());
     } else if (link.scheme().contains(QLatin1String("tp")))
         QDesktopServices::openUrl(link);
 }
@@ -287,9 +283,10 @@ void MsgCtxtView::noteEditAccepted()
     pos.form = m_editor->noteIndex();
     m_catalog->push(new SetNoteCmd(m_catalog, pos, m_editor->note()));
 
-    m_prevEntry.entry = -1; process();
-    //m_stackedLayout->setCurrentIndex(0);
-    //m_unfinishedNotes.remove(m_entry);
+    m_prevEntry.entry = -1;
+    process();
+    // m_stackedLayout->setCurrentIndex(0);
+    // m_unfinishedNotes.remove(m_entry);
     noteEditRejected();
 }
 void MsgCtxtView::noteEditRejected()
@@ -299,7 +296,7 @@ void MsgCtxtView::noteEditRejected()
     Q_EMIT escaped();
 }
 
-void MsgCtxtView::addNote(DocPosition p, const QString& text)
+void MsgCtxtView::addNote(DocPosition p, const QString &text)
 {
     p.form = -1;
     m_catalog->push(new SetNoteCmd(m_catalog, p, Note(text)));
@@ -309,7 +306,7 @@ void MsgCtxtView::addNote(DocPosition p, const QString& text)
     }
 }
 
-void MsgCtxtView::addTemporaryEntryNote(int entry, const QString& text)
+void MsgCtxtView::addTemporaryEntryNote(int entry, const QString &text)
 {
     m_tempNotes.insert(entry, text);
     m_prevEntry.entry = -1;
@@ -318,7 +315,8 @@ void MsgCtxtView::addTemporaryEntryNote(int entry, const QString& text)
 
 void MsgCtxtView::removeErrorNotes()
 {
-    if (!m_hasErrorNotes) return;
+    if (!m_hasErrorNotes)
+        return;
 
     DocPosition p = m_entry.toDocPosition();
     const QVector<Note> notes = m_catalog->notes(p);
