@@ -13,12 +13,12 @@
 #include "pos.h"
 #include "tmentry.h"
 
-#include <QThreadPool>
 #include <QRunnable>
+#include <QThreadPool>
 
-#include <QString>
 #include <QMutex>
 #include <QSqlDatabase>
+#include <QString>
 class QSqlQuery;
 
 /**
@@ -29,27 +29,29 @@ namespace TM
 
 #define TM_DATABASE_EXTENSION ".db"
 #define REMOTETM_DATABASE_EXTENSION ".remotedb"
-enum DbType {Local, Remote, Undefined}; //is needed only on opening
+enum DbType {
+    Local,
+    Remote,
+    Undefined,
+}; // is needed only on opening
 
 #define TM_AREA 8111
 
-
-QThreadPool* threadPool();
-
+QThreadPool *threadPool();
 
 #define CLOSEDB 10001
-#define OPENDB  10000
-#define TMTABSELECT  100
-#define UPDATE  80
-#define REMOVE  70
-#define REMOVEFILE  69
-#define INSERT  60
-#define SELECT  50
-#define BATCHSELECTFINISHED  49
+#define OPENDB 10000
+#define TMTABSELECT 100
+#define UPDATE 80
+#define REMOVE 70
+#define REMOVEFILE 69
+#define INSERT 60
+#define SELECT 50
+#define BATCHSELECTFINISHED 49
 #define IMPORT 30
 #define EXPORT 25
-#define REMOVEMISSINGFILES    11
-#define SCAN    10
+#define REMOVEMISSINGFILES 11
+#define SCAN 10
 #define SCANFINISHED 9
 
 struct TMConfig {
@@ -59,7 +61,7 @@ struct TMConfig {
     QString targetLangCode;
 };
 
-void cancelAllJobs(); //HACK because threadweaver's dequeue is not workin'
+void cancelAllJobs(); // HACK because threadweaver's dequeue is not workin'
 
 /**
  * @brief Base class for QRunnable jobs
@@ -75,8 +77,8 @@ public:
     virtual int priority() const = 0;
 };
 
-//called on startup
-class OpenDBJob: public QObject, public QRunnable, public Job
+// called on startup
+class OpenDBJob : public QObject, public QRunnable, public Job
 {
     Q_OBJECT
 public:
@@ -88,7 +90,7 @@ public:
         }
     };
 
-    explicit OpenDBJob(const QString& dbName, DbType type = TM::Local, bool reconnect = false, const ConnectionParams& connParams = ConnectionParams());
+    explicit OpenDBJob(const QString &dbName, DbType type = TM::Local, bool reconnect = false, const ConnectionParams &connParams = ConnectionParams());
     ~OpenDBJob() override = default;
 
     int priority() const override
@@ -98,22 +100,27 @@ public:
 
     struct DBStat {
         int pairsCount, uniqueSourcesCount, uniqueTranslationsCount;
-        DBStat(): pairsCount(0), uniqueSourcesCount(0), uniqueTranslationsCount(0) {}
+        DBStat()
+            : pairsCount(0)
+            , uniqueSourcesCount(0)
+            , uniqueTranslationsCount(0)
+        {
+        }
     };
 
 protected:
     void run() override;
 
 Q_SIGNALS:
-    void done(OpenDBJob*);
+    void done(OpenDBJob *);
 
 public:
     QString m_dbName;
     DbType m_type;
-    //statistics
+    // statistics
     DBStat m_stat;
 
-    //for the new DB creation
+    // for the new DB creation
     TMConfig m_tmConfig;
     bool m_setParams{false};
 
@@ -122,12 +129,12 @@ public:
     ConnectionParams m_connParams;
 };
 
-//called on startup
-class CloseDBJob: public QObject, public QRunnable, public Job
+// called on startup
+class CloseDBJob : public QObject, public QRunnable, public Job
 {
     Q_OBJECT
 public:
-    explicit CloseDBJob(const QString& dbName);
+    explicit CloseDBJob(const QString &dbName);
     ~CloseDBJob();
 
     int priority() const override
@@ -140,27 +147,24 @@ public:
     }
 
 Q_SIGNALS:
-    void done(CloseDBJob*);
+    void done(CloseDBJob *);
 
 protected:
     void run() override;
 
     QString m_dbName;
-    //statistics?
+    // statistics?
 };
 
-
-
-
-class SelectJob: public QObject, public QRunnable, public Job
+class SelectJob : public QObject, public QRunnable, public Job
 {
     Q_OBJECT
 public:
-    SelectJob(const CatalogString& source,
-              const QString& ctxt,
-              const QString& file,
-              const DocPosition&,//for back tracking
-              const QString& dbName);
+    SelectJob(const CatalogString &source,
+              const QString &ctxt,
+              const QString &file,
+              const DocPosition &, // for back tracking
+              const QString &dbName);
     ~SelectJob() = default;
 
     int priority() const override
@@ -169,20 +173,19 @@ public:
     }
 
 Q_SIGNALS:
-    void done(SelectJob*);
+    void done(SelectJob *);
 
 protected:
     void run() override;
-    //void aboutToBeDequeued(ThreadWeaver::WeaverInterface*); KDE5PORT
+    // void aboutToBeDequeued(ThreadWeaver::WeaverInterface*); KDE5PORT
 
 private:
-    //returns true if seen translation with >85%
-    bool doSelect(QSqlDatabase&,
-                  QStringList& words,
-                  bool isShort);
+    // returns true if seen translation with >85%
+    bool doSelect(QSqlDatabase &, QStringList &words, bool isShort);
 
 public:
     CatalogString m_source;
+
 private:
     QString m_ctxt;
     QString m_file;
@@ -195,15 +198,17 @@ public:
     QString m_dbName;
 };
 
-enum {NoEnqueue = 0, Enqueue = 1};
-SelectJob* initSelectJob(Catalog*, DocPosition pos, QString db = QString(), int opt = Enqueue);
+enum {
+    NoEnqueue = 0,
+    Enqueue = 1,
+};
+SelectJob *initSelectJob(Catalog *, DocPosition pos, QString db = QString(), int opt = Enqueue);
 
-
-class RemoveMissingFilesJob: public QObject, public QRunnable, public Job
+class RemoveMissingFilesJob : public QObject, public QRunnable, public Job
 {
     Q_OBJECT
 public:
-    explicit RemoveMissingFilesJob(const QString& dbName);
+    explicit RemoveMissingFilesJob(const QString &dbName);
     ~RemoveMissingFilesJob();
     int priority() const override
     {
@@ -219,11 +224,11 @@ Q_SIGNALS:
     void done();
 };
 
-class RemoveFileJob: public QObject, public QRunnable, public Job
+class RemoveFileJob : public QObject, public QRunnable, public Job
 {
     Q_OBJECT
 public:
-    explicit RemoveFileJob(const QString& filePath, const QString& dbName, QObject *parent = nullptr);
+    explicit RemoveFileJob(const QString &filePath, const QString &dbName, QObject *parent = nullptr);
     ~RemoveFileJob();
     int priority() const override
     {
@@ -241,12 +246,11 @@ Q_SIGNALS:
     void done();
 };
 
-
-class RemoveJob: public QObject, public QRunnable, public Job
+class RemoveJob : public QObject, public QRunnable, public Job
 {
     Q_OBJECT
 public:
-    explicit RemoveJob(const TMEntry& entry);
+    explicit RemoveJob(const TMEntry &entry);
     ~RemoveJob();
     int priority() const override
     {
@@ -262,28 +266,29 @@ Q_SIGNALS:
     void done();
 };
 
-
 /**
  * used to eliminate a lot of duplicate entries
  *
  * it is supposed to run on entry switch/file close in Editor
-**/
-//TODO a mechanism to get rid of dead dups (use strigi?).
-//also, display usage of different translations and suggest user
-//to use only one of them (listview, checkboxes)
-class UpdateJob: public QRunnable, public Job
+ **/
+// TODO a mechanism to get rid of dead dups (use strigi?).
+// also, display usage of different translations and suggest user
+// to use only one of them (listview, checkboxes)
+class UpdateJob : public QRunnable, public Job
 {
 public:
-    explicit UpdateJob(const QString& filePath,
-                       const QString& ctxt,
-                       const CatalogString& en,
-                       const CatalogString& newTarget,
+    explicit UpdateJob(const QString &filePath,
+                       const QString &ctxt,
+                       const CatalogString &en,
+                       const CatalogString &newTarget,
                        int form,
                        bool approved,
-                       //const DocPosition&,//for back tracking
-                       const QString& dbName);
+                       // const DocPosition&,//for back tracking
+                       const QString &dbName);
 
-    ~UpdateJob() {}
+    ~UpdateJob()
+    {
+    }
 
     int priority() const override
     {
@@ -303,11 +308,11 @@ private:
     QString m_dbName;
 };
 
-//scan one file
-class ScanJob: public QRunnable, public Job
+// scan one file
+class ScanJob : public QRunnable, public Job
 {
 public:
-    explicit ScanJob(const QString& filePath, const QString& dbName);
+    explicit ScanJob(const QString &filePath, const QString &dbName);
     ~ScanJob() override = default;
 
     int priority() const override
@@ -317,26 +322,27 @@ public:
 
 protected:
     void run() override;
+
 public:
     QString m_filePath;
 
-    //statistics
+    // statistics
     ushort m_time;
     ushort m_added;
-    ushort m_newVersions;//e1.english==e2.english, e1.target!=e2.target
+    ushort m_newVersions; // e1.english==e2.english, e1.target!=e2.target
 
     int m_size;
 
     QString m_dbName;
 };
 
-class ScanJobFeedingBack: public QObject, public ScanJob
+class ScanJobFeedingBack : public QObject, public ScanJob
 {
     Q_OBJECT
 public:
-    explicit ScanJobFeedingBack(const QString& filePath,
-                                const QString& dbName)
-        : QObject(), ScanJob(filePath, dbName)
+    explicit ScanJobFeedingBack(const QString &filePath, const QString &dbName)
+        : QObject()
+        , ScanJob(filePath, dbName)
     {
         setAutoDelete(false);
     }
@@ -349,18 +355,20 @@ protected:
     }
 
 Q_SIGNALS:
-    void done(ScanJobFeedingBack*);
+    void done(ScanJobFeedingBack *);
 };
 
-//helper
-class BatchSelectFinishedJob: public QObject, public QRunnable, public Job
+// helper
+class BatchSelectFinishedJob : public QObject, public QRunnable, public Job
 {
     Q_OBJECT
 public:
-    explicit BatchSelectFinishedJob(QWidget* view)
-        : QObject(), QRunnable()
+    explicit BatchSelectFinishedJob(QWidget *view)
+        : QObject()
+        , QRunnable()
         , m_view(view)
-    {}
+    {
+    }
     ~BatchSelectFinishedJob() override = default;
 
     int priority() const override
@@ -376,8 +384,9 @@ protected:
     {
         Q_EMIT done();
     }
+
 public:
-    QWidget* m_view;
+    QWidget *m_view;
 };
 #if 0
 we use index stored in db now...
@@ -406,16 +415,10 @@ public:
 };
 #endif
 
-
-
-
-
-
-class ImportTmxJob: public QRunnable, public Job
+class ImportTmxJob : public QRunnable, public Job
 {
 public:
-    explicit ImportTmxJob(const QString& url,
-                          const QString& dbName);
+    explicit ImportTmxJob(const QString &url, const QString &dbName);
     ~ImportTmxJob();
 
     int priority() const override
@@ -425,10 +428,11 @@ public:
 
 protected:
     void run() override;
+
 public:
     QString m_filename;
 
-    //statistics
+    // statistics
     ushort m_time{0};
 
     QString m_dbName;
@@ -436,11 +440,10 @@ public:
 
 // #if 0
 
-class ExportTmxJob: public QRunnable, public Job
+class ExportTmxJob : public QRunnable, public Job
 {
 public:
-    explicit ExportTmxJob(const QString& url,
-                          const QString& dbName);
+    explicit ExportTmxJob(const QString &url, const QString &dbName);
     ~ExportTmxJob();
 
     int priority() const override
@@ -450,10 +453,11 @@ public:
 
 protected:
     void run() override;
+
 public:
     QString m_filename;
 
-    //statistics
+    // statistics
     ushort m_time{0};
 
     QString m_dbName;
@@ -461,11 +465,11 @@ public:
 
 // #endif
 
-class ExecQueryJob: public QObject, public QRunnable, public Job
+class ExecQueryJob : public QObject, public QRunnable, public Job
 {
     Q_OBJECT
 public:
-    explicit ExecQueryJob(const QString& queryString, const QString& dbName, QMutex *dbOperation);
+    explicit ExecQueryJob(const QString &queryString, const QString &dbName, QMutex *dbOperation);
     ~ExecQueryJob();
 
     int priority() const override
@@ -473,23 +477,20 @@ public:
         return TMTABSELECT;
     }
 
-
-    QSqlQuery* query{nullptr};
+    QSqlQuery *query{nullptr};
 
 Q_SIGNALS:
-    void done(ExecQueryJob*);
+    void done(ExecQueryJob *);
 
 protected:
     void run() override;
 
     QString m_dbName;
     QString m_query;
-    QMutex* m_dbOperationMutex;
-    //statistics?
+    QMutex *m_dbOperationMutex;
+    // statistics?
 };
 
 }
 
-
 #endif
-
