@@ -115,7 +115,7 @@ void TMDBModel::setFilter(const QString &source, const QString &target, bool inv
     } else if (m_queryType == WordOrder) {
         /*escapedSource.replace('%',"\b%");escapedSource.replace('_',"\b_");
         escapedTarget.replace('%',"\b%");escapedTarget.replace('_',"\b_");*/
-        const QRegularExpression wre(QStringLiteral("\\W"));
+        const QRegularExpression wre(QStringLiteral("\\W"), QRegularExpression::UseUnicodePropertiesOption);
         QStringList sourceList = escapedSource.split(wre, Qt::SkipEmptyParts);
         QStringList targetList = escapedTarget.split(wre, Qt::SkipEmptyParts);
 
